(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    111884,       2633]
NotebookOptionsPosition[    106130,       2445]
NotebookOutlinePosition[    106742,       2471]
CellTagsIndexPosition[    106655,       2466]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Claisen Reaction of Allyl Vinyl Ether DG-EVB in redundant internal \
coordinates\
\>", "Subtitle",
 CellChangeTimes->{{3.4215931314915*^9, 3.421593171624607*^9}}],

Cell[TextData[{
 StyleBox["Notes:",
  FontWeight->"Bold"],
 "\n   \nThis notebook reads fchk files containing coordinates, energies, \
gradients and hessians for reactant, product, transition state, and \
additional points on the surface.\n\n###############\n Gaussian stores all \
values in a.u. and standard orientation in the fchk file\n\n Distance = bohrs\
\n Angles = radian\n Energy = hartree\n Gradient = hartree/bohr\n Hessian = \
hartree/bohr^2\n###############\n\nThe notebook reads an IRC fchk file (from \
the HPC IRC following algorithm located in L123.exe, the corrected \
coordinates and energies are read)\n\nA reduced number of internal \
coordinates can be used to fit V12sq (see the EVB Surface Fitting section)\nA \
reduced number of points can be used for the distributed Gussian fit (see the \
EVB Surface Fitting section)\n\nTo perform an EVB fit, update the \
SetDirectory statement and any other options in input section, then evaluate \
the outermost cell over here.  ",
 StyleBox["---------------------------->",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.4211658572262583`*^9, 3.421165860565464*^9}, {
  3.421165918505851*^9, 3.4211659992892523`*^9}, {3.421583346865282*^9, 
  3.421583425893856*^9}, {3.421583527849957*^9, 3.421583568182987*^9}, {
  3.421583926020019*^9, 3.421583926485379*^9}}],

Cell[CellGroupData[{

Cell["Preliminaries", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"$TextStyle", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
    RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"FontFamily", "\[Rule]", "\<\"Helvetica\"\>"}], ",", 
   RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.421593524695475*^9, 3.4215953633862762`*^9, 3.421595640170068*^9, 
   3.4216023465828857`*^9, 3.435092441295*^9, 3.4350925152799997`*^9, 
   3.4350928458380003`*^9, 3.436116939515625*^9, 3.436132191171875*^9, 
   3.436137609859375*^9, 3.436184600765625*^9, 3.436189415875*^9, 
   3.436190856203125*^9, 3.436191946078125*^9, 3.436194354578125*^9, 
   3.436196137921875*^9, 3.43619845515625*^9, 3.436202322328125*^9, 
   3.436206013015625*^9, 3.436565348974125*^9, 3.436619006161625*^9, 
   3.43716263094275*^9, {3.437231088177125*^9, 3.43723110250525*^9}, 
   3.437327564880866*^9, 3.4373957371026897`*^9, 3.43739905229326*^9, 
   3.4373991034147053`*^9, {3.4374086349525557`*^9, 3.437408639711499*^9}, 
   3.437412931699115*^9, 3.4374133483979177`*^9, 3.437413404677442*^9, 
   3.4374284404324427`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"<<", "Chemistry`EVB`"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input", "Section"],

Cell["\<\
To avoid clobbering variables of similiar names, please use variable names of \
the form iName to hold input data.\
\>", "Text",
 CellChangeTimes->{{3.4214181842223473`*^9, 3.421418184645219*^9}, 
   3.421583494000621*^9}],

Cell[CellGroupData[{

Cell["Set working directory", "Subsection",
 ScreenStyleEnvironment->"Presentation",
 PrintingStyleEnvironment->"Presentation",
 ShowCellLabel->False,
 Magnification->1.25],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{
    "SetDirectory", "[", 
     "\"\</Users/jsonnenb/Documents/Research/ONR/EVB fits/Claisen_gas_61\>\"",
      "]"}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "SetDirectory", "[", 
      "\"\<C:\\Documents and Settings\\Schlegel \
Group\\Desktop\\Claisen_gas_61\>\"", "]"}], ";"}], " ", "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.421593396987987*^9, 3.42159339829801*^9}, {
   3.4350661981666627`*^9, 3.4350662109696627`*^9}, {3.435092470855*^9, 
   3.4350924974230003`*^9}, 3.4350928496400003`*^9, {3.436116650890625*^9, 
   3.43611666428125*^9}, {3.43611689278125*^9, 3.43611693425*^9}, {
   3.4373273879800673`*^9, 3.4373273961719637`*^9}, 3.437327481141327*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
File names. All files must have the same number of redundant internal \
coordinates. \
\>", "Subsection",
 ScreenStyleEnvironment->"Presentation",
 PrintingStyleEnvironment->"Presentation",
 ShowCellLabel->False,
 Magnification->1.25],

Cell[BoxData[{
 RowBox[{
  RowBox[{"iReactant", "=", "\"\<claisen_R_61.fchk\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iProduct", "=", "\"\<claisen_P_61.fchk\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iTS", "=", "\"\<claisen_TS_61.fchk\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iOtherPoints", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<claisen_1.5.fchk\>\"", ",", "\"\<claisen_minus_1.5.fchk\>\"", ",", 
     "\"\<claisen_6.fchk\>\"", ",", "\"\<claisen_minus_6.fchk\>\"", ",", 
     "\"\<claisen_10.fchk\>\"", ",", "\"\<claisen_minus_10.fchk\>\"", ",", 
     "\"\<claisen_3.0.fchk\>\""}], "}"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{
    "data", " ", "points", " ", "along", " ", "IRC", " ", "that", " ", "are", 
     " ", "used", " ", "for", " ", "analyzing", " ", "the", " ", "EVB", " ", 
     RowBox[{"fit", "."}]}], " ", "*)"}],
   FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"IRCFile", "=", "\"\<claisen_TS_irc_neg_calcall.fchk\>\""}], 
   ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"A", " ", "2"}], "-", 
     RowBox[{"D", " ", "PES", " ", 
      RowBox[{"scan", "."}]}]}], " ", "*)"}],
   FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"GridFile", "=", "\"\<\>\""}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"GridCoordX", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"GridCoordY", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Ngrid", "=", "0"}], ";"}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Repulsive Term coordinates", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"icoordV11", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"icoordV22", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Control the use of gradients and Hessians in the DG fit at points other than \
the TS.\
\>", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"iNoGrad", "=", "False"}], ";", 
  RowBox[{"iNoHess", "=", "False"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Enable figure file generation for manuscripts and the like.", \
"Subsection",
 ScreenStyleEnvironment->"Presentation",
 PrintingStyleEnvironment->"Presentation",
 ShowCellLabel->False,
 Magnification->1.25],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"iFigures", "=", "0"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.421593526241948*^9, 3.421595366063532*^9, 3.421595641960476*^9, 
   3.421602349926886*^9, 3.4350924421610003`*^9, 3.435092515427*^9, 
   3.43509285558*^9, 3.43611694134375*^9, 3.436132191359375*^9, 
   3.436137610046875*^9, 3.436184604640625*^9, 3.43618941609375*^9, 
   3.436190856375*^9, 3.43619194625*^9, 3.43619435475*^9, 3.43619613809375*^9,
    3.436198455328125*^9, 3.4362023225*^9, 3.4362060131875*^9, 
   3.436565366396*^9, 3.436619006505375*^9, 3.43716263694275*^9, {
   3.437231093849*^9, 3.437231102739625*^9}, 3.437327574991246*^9, 
   3.4373957410360518`*^9, 3.437399055387291*^9, 3.437399110839911*^9, 
   3.437408643663184*^9, 3.437412932619117*^9, 3.437413349776606*^9, 
   3.437413405352298*^9, 3.4374284442998962`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Enable use of previously determined beta as starting guess.", \
"Subsection",
 ScreenStyleEnvironment->"Presentation",
 PrintingStyleEnvironment->"Presentation",
 ShowCellLabel->False,
 CellChangeTimes->{{3.434827059397477*^9, 3.434827075946116*^9}},
 Magnification->1.25],

Cell[BoxData[
 RowBox[{
  RowBox[{"iBeta", "=", "True"}], ";"}]], "Input",
 CellChangeTimes->{
  3.4348269884069633`*^9, {3.434827084349894*^9, 3.434827102376202*^9}, {
   3.435000846343*^9, 3.435000848028*^9}, {3.435007303237*^9, 
   3.435007304959*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Enable debugging checks and dump printing.", "Subsection",
 ScreenStyleEnvironment->"Presentation",
 PrintingStyleEnvironment->"Presentation",
 ShowCellLabel->False,
 Magnification->1.25],

Cell[BoxData[
 RowBox[{
  RowBox[{"iDebug", "=", "10"}], ";", 
  RowBox[{"iDump", "=", "0"}], ";"}]], "Input",
 CellChangeTimes->{
  3.435092148408*^9, {3.435092784962*^9, 3.435092785434*^9}, {3.4350941654*^9,
    3.435094165744*^9}, 3.436121265640625*^9, {3.436121861625*^9, 
   3.436121887703125*^9}, 3.436132483859375*^9, 3.436132843546875*^9, 
   3.43619295903125*^9, 3.43619435075*^9, 3.43724467725525*^9, 
   3.437244712395875*^9, 3.437244753724*^9, 3.437255067802125*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions", "Section"],

Cell[CellGroupData[{

Cell["Display MB of memory currently in use", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MBinUse", "[", "]"}], ":=", 
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Currently using \>\"", ",", 
    RowBox[{"N", "[", 
     RowBox[{
      RowBox[{"MemoryInUse", "[", "]"}], "/", 
      SuperscriptBox["2", "20"]}], "]"}], ",", "\"\< MB of memory.\>\""}], 
   "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Condition Number of a matrix. May blow up if the matrix is not invertible.\
\>", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OneNorm", "[", "m_", "]"}], ":=", 
  RowBox[{"Max", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Norm", "[", 
       RowBox[{"#", ",", "1"}], "]"}], "&"}], ",", "m"}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TwoNorm", "[", "m_", "]"}], ":=", 
  RowBox[{"Max", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Norm", "[", 
       RowBox[{"#", ",", "2"}], "]"}], "&"}], ",", "m"}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ConditionNumber2", "[", "m_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"TwoNorm", "[", 
    RowBox[{"Inverse", "[", "m", "]"}], "]"}], "*", 
   RowBox[{"TwoNorm", "[", "m", "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ConditionNumber", "[", "m_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"OneNorm", "[", 
    RowBox[{"Inverse", "[", "m", "]"}], "]"}], "*", 
   RowBox[{"OneNorm", "[", "m", "]"}]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBinUse", "[", "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Currently using \"\>", "\[InvisibleSpace]", 
   "8.631675720214844`", "\[InvisibleSpace]", "\<\" MB of memory.\"\>"}],
  SequenceForm["Currently using ", 8.631675720214844, " MB of memory."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.421593527210681*^9, 3.421595367093377*^9, 3.421595642945067*^9, 
   3.421602350453456*^9, 3.4350924422349997`*^9, 3.435092515484*^9, 
   3.435092912303*^9, 3.436116947734375*^9, 3.436121414515625*^9, 
   3.43613219146875*^9, 3.436137610171875*^9, 3.4361846050625*^9, 
   3.436189416234375*^9, 3.4361908565*^9, 3.436191946375*^9, 
   3.436194354875*^9, 3.43619613821875*^9, 3.436198455453125*^9, 
   3.436202322609375*^9, 3.4362060133125*^9, 3.436565367942875*^9, 
   3.43661900667725*^9, 3.437162637927125*^9, {3.437231093989625*^9, 
   3.437231102864625*^9}, 3.43732757864081*^9, 3.437395741851823*^9, 
   3.4373990557583237`*^9, 3.437399113669359*^9, 3.4374086498447027`*^9, 
   3.43741293402216*^9, 3.437413350168064*^9, 3.4374134056900463`*^9, 
   3.437428444937237*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate EVB surface", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nDG", "=", "3"}]], "Input",
 CellChangeTimes->{
  3.421594049622143*^9, 3.421595624339498*^9, 3.4216023290974894`*^9, {
   3.4361169555625*^9, 3.4361169565625*^9}, 3.436117162671875*^9, 
   3.43612141059375*^9, 3.4361219589375*^9, 3.43612513821875*^9, 
   3.43613248734375*^9, 3.43613257978125*^9, 3.436132848109375*^9, {
   3.436194348296875*^9, 3.436194348546875*^9}, 3.4372550625365*^9, {
   3.43725510069275*^9, 3.437255186927125*^9}, 3.437331071833644*^9, 
   3.4373957048882017`*^9}],

Cell[BoxData["3"], "Output",
 CellChangeTimes->{
  3.421593527416809*^9, 3.421593963815804*^9, 3.421594051919518*^9, 
   3.421594273474373*^9, 3.421595103674*^9, 3.421595367274531*^9, 
   3.421595643066065*^9, 3.4216023506572866`*^9, 3.4350924422539997`*^9, 
   3.435092515502*^9, 3.435092797602*^9, 3.435092885791*^9, 3.435093216722*^9,
    3.436117189203125*^9, 3.436117310015625*^9, 3.43611950328125*^9, 
   3.43612127003125*^9, 3.43612141578125*^9, 3.436121490421875*^9, 
   3.436121586890625*^9, 3.43612170684375*^9, 3.43612179009375*^9, {
   3.4361218695*^9, 3.43612189046875*^9}, {3.43612195090625*^9, 
   3.43612196140625*^9}, 3.436122098359375*^9, 3.43612437071875*^9, 
   3.43612456390625*^9, 3.436124799546875*^9, 3.436125142140625*^9, 
   3.436126306109375*^9, 3.4361268211875*^9, 3.436128308859375*^9, 
   3.436129062390625*^9, {3.43612940484375*^9, 3.43612942334375*^9}, 
   3.43612969353125*^9, 3.436130644828125*^9, 3.436131066453125*^9, 
   3.43613146559375*^9, 3.436131953796875*^9, 3.436132191515625*^9, 
   3.436132489578125*^9, 3.436132581828125*^9, 3.436132832421875*^9, 
   3.43613287771875*^9, 3.43613526190625*^9, 3.43613621546875*^9, 
   3.436137610234375*^9, 3.43618460515625*^9, 3.43618941628125*^9, 
   3.436190856546875*^9, 3.436191946421875*^9, 3.436193097046875*^9, 
   3.436194354921875*^9, 3.43619613825*^9, 3.436198455484375*^9, 
   3.436202322671875*^9, 3.436206013359375*^9, 3.436565368146*^9, 
   3.436619006724125*^9, 3.437162638114625*^9, {3.437231081474*^9, 
   3.4372311030365*^9}, 3.437244720224*^9, 3.437244757552125*^9, 
   3.4372550264115*^9, 3.437255071270875*^9, {3.437255102958375*^9, 
   3.437255167614625*^9}, 3.4373275789135513`*^9, 3.43733107418781*^9, 
   3.437395742081045*^9, 3.437399056173801*^9, 3.437399114577737*^9, 
   3.4374086538093243`*^9, 3.437412934136491*^9, 3.437413350283654*^9, 
   3.437413406047739*^9, 3.437428445349247*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Historic \[Alpha] values", "Subsubsection",
 CellChangeTimes->{{3.436117035390625*^9, 3.436117043296875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"reactant", ",", " ", "product", ",", " ", "TS", ",", " ", 
    RowBox[{"others", ";", " ", 
     RowBox[{
      RowBox[{"except", " ", "for", " ", "nDG"}], "=", "1"}]}]}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"UseRP", "=", "True"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Switch", "[", 
     RowBox[{"nDG", ",", "\[IndentingNewLine]", "10", ",", 
      RowBox[{
       RowBox[{"alpha", "=", 
        RowBox[{"{", 
         RowBox[{
         "4.7191002969000015`", ",", "4.7191002969000015`", ",", "7.", ",", 
          "4.7191002969000015`", ",", "4.7191002969000015`", ",", 
          "4.7191002969000015`", ",", "4.7191002969000015`", ",", 
          "4.7191002969000015`", ",", "4.7191002969000015`", ",", "5.5`"}], 
         "}"}]}], ";"}], ",", "\[IndentingNewLine]", "9", ",", 
      RowBox[{
       RowBox[{"alpha", "=", 
        RowBox[{"{", 
         RowBox[{
         "2.93019", ",", "2.93019", ",", "2.93019", ",", "2.93019", ",", 
          "2.93019", ",", "2.93019", ",", "2.93019", ",", "2.93019", ",", 
          "2.93019"}], "}"}]}], ";"}], ",", "\[IndentingNewLine]", "7", ",", 
      RowBox[{
       RowBox[{"alpha", "=", 
        RowBox[{"{", 
         RowBox[{
         "2.299", ",", "2.299", ",", "2.299", ",", "2.299", ",", "2.299", ",",
           "2.299", ",", "2.299"}], "}"}]}], ";"}], ",", 
      "\[IndentingNewLine]", "5", ",", 
      RowBox[{
       RowBox[{"alpha", "=", 
        RowBox[{"{", 
         RowBox[{".8", ",", ".84", ",", "5.1", ",", "0.4", ",", "0.4"}], 
         "}"}]}], ";"}], ",", "\[IndentingNewLine]", "4", ",", 
      RowBox[{
       RowBox[{"alpha", "=", 
        RowBox[{"{", 
         RowBox[{"0.3", ",", "0.4", ",", "1.5", ",", "0.5"}], "}"}]}], ";"}], 
      ",", "\[IndentingNewLine]", "3", ",", 
      RowBox[{
       RowBox[{"alpha", "=", 
        RowBox[{"{", 
         RowBox[{"1.3", ",", "6.0", ",", "2."}], "}"}]}], ";"}], ",", 
      "\[IndentingNewLine]", "1", ",", 
      RowBox[{
       RowBox[{"alpha", "=", 
        RowBox[{"{", "8.589230426622896`", "}"}]}], ";", 
       RowBox[{"UseRP", "=", "False"}], ";"}]}], "\[IndentingNewLine]", "]"}],
     ";"}]}]}]], "Input",
 CellChangeTimes->{{3.421594214990321*^9, 3.421594215365445*^9}, {
  3.421594259588469*^9, 3.421594260543841*^9}}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"reactant", ",", " ", "product", ",", " ", "TS", ",", " ", 
    RowBox[{"others", ";", " ", 
     RowBox[{
      RowBox[{"except", " ", "for", " ", "nDG"}], "=", "1"}]}]}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"UseRP", "=", "True"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Switch", "[", 
     RowBox[{"nDG", ",", "\[IndentingNewLine]", 
      StyleBox["10",
       FontColor->GrayLevel[0]], ",", 
      RowBox[{
       RowBox[{"alpha", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"1.", ",", 
          RowBox[{"{", "nDG", "}"}]}], "]"}]}], ";"}], ",", 
      "\[IndentingNewLine]", 
      StyleBox["9",
       FontColor->GrayLevel[0]], ",", 
      RowBox[{
       RowBox[{"alpha", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"2.1", ",", 
          RowBox[{"{", "nDG", "}"}]}], "]"}]}], ";"}], ",", 
      "\[IndentingNewLine]", "7", ",", 
      RowBox[{
       RowBox[{"alpha", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"0.75", ",", 
          RowBox[{"{", "nDG", "}"}]}], "]"}]}], ";"}], ",", 
      "\[IndentingNewLine]", 
      StyleBox["5",
       FontColor->GrayLevel[0]], ",", 
      RowBox[{
       RowBox[{"alpha", "=", 
        RowBox[{"{", 
         RowBox[{".8", ",", ".84", ",", "5.1", ",", "0.4", ",", "0.4"}], 
         "}"}]}], ";"}], ",", "\[IndentingNewLine]", 
      StyleBox["4",
       FontColor->GrayLevel[0]], ",", 
      RowBox[{
       RowBox[{"alpha", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"0.5", ",", 
          RowBox[{"{", "nDG", "}"}]}], "]"}]}], ";"}], ",", 
      "\[IndentingNewLine]", 
      StyleBox["3",
       FontColor->GrayLevel[0]], ",", 
      RowBox[{
       RowBox[{"alpha", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"1.5", ",", 
          RowBox[{"{", "nDG", "}"}]}], "]"}]}], ";"}], ",", 
      "\[IndentingNewLine]", "1", ",", 
      RowBox[{
       RowBox[{"alpha", "=", 
        RowBox[{"{", "8.589230426622896`", "}"}]}], ";", 
       RowBox[{"UseRP", "=", "False"}], ";"}]}], "\[IndentingNewLine]", "]"}],
     ";"}]}]}]], "Input",
 CellChangeTimes->{{3.421594214990321*^9, 3.421594215365445*^9}, {
   3.421594259588469*^9, 3.421594260543841*^9}, {3.436117088875*^9, 
   3.43611712953125*^9}, {3.436117170734375*^9, 3.436117173453125*^9}, 
   3.436117293703125*^9, {3.436119378359375*^9, 3.436119381921875*^9}, {
   3.436121405921875*^9, 3.43612140634375*^9}, {3.436121486125*^9, 
   3.43612148659375*^9}, {3.43612158165625*^9, 3.43612158340625*^9}, 
   3.436121673203125*^9, {3.436121784359375*^9, 3.43612178621875*^9}, 
   3.436121939546875*^9, 3.436122091765625*^9, 3.436124366890625*^9, 
   3.43612455953125*^9, 3.436124795078125*^9, 3.4361249885625*^9, 
   3.436125133046875*^9, 3.436126294625*^9, {3.436126815625*^9, 
   3.436126818046875*^9}, {3.436128305265625*^9, 3.436128305421875*^9}, 
   3.436129058890625*^9, {3.4361293929375*^9, 3.436129393390625*^9}, 
   3.4361296789375*^9, {3.436130636421875*^9, 3.436130641484375*^9}, {
   3.436131063484375*^9, 3.436131063859375*^9}, 3.436131461984375*^9, {
   3.436131930703125*^9, 3.4361319495*^9}, {3.43613218309375*^9, 
   3.436132184234375*^9}, 3.436132447234375*^9, {3.436132863875*^9, 
   3.4361328690625*^9}, {3.436135205625*^9, 3.436135256625*^9}, 
   3.436136210765625*^9, {3.436137605375*^9, 3.436137606921875*^9}, 
   3.436184594484375*^9, 3.43618941121875*^9, {3.43619085125*^9, 
   3.43619085178125*^9}, 3.43619191465625*^9, 3.436192944859375*^9, 
   3.43619613453125*^9, {3.43619845115625*^9, 3.43619845159375*^9}, {
   3.43620231890625*^9, 3.436202319125*^9}, {3.436206008984375*^9, 
   3.436206009515625*^9}, 3.436565340849125*^9, {3.436619000567875*^9, 
   3.436619000974125*^9}, 3.437162624724*^9, {3.43724467063025*^9, 
   3.4372446707865*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"previously", " ", "determined", " ", "$B", " ", "values"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"betafilename", "=", 
     RowBox[{"\"\<Beta-\>\"", "<>", 
      RowBox[{"ToString", "[", "nDG", "]"}], "<>", "\"\<.txt\>\""}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Count", "[", 
         RowBox[{
          RowBox[{"FileNames", "[", "]"}], ",", "betafilename"}], "]"}], 
        "\[Equal]", "1"}], " ", "&&", " ", "iBeta"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Guess", "=", 
        RowBox[{"ReadList", "[", 
         RowBox[{"betafilename", ",", "Number"}], "]"}]}], ";"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Guess", "=", "Automatic"}], ";"}]}], "\[IndentingNewLine]", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Length", "[", "Guess", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.434826774981058*^9, 3.434826813971819*^9}, 
   3.434827020475934*^9, {3.434827118861854*^9, 3.434827137802361*^9}, {
   3.4348272794057903`*^9, 3.434827283568796*^9}, {3.4348274080212593`*^9, 
   3.434827480216357*^9}, {3.434827634674159*^9, 3.4348276792732973`*^9}, {
   3.434827751919635*^9, 3.4348277813294573`*^9}, {3.434829639050087*^9, 
   3.434829640813073*^9}, {3.43482969597332*^9, 3.434829777685588*^9}, {
   3.4348299842914867`*^9, 3.434830014241911*^9}, {3.434830124518196*^9, 
   3.434830139091716*^9}, {3.434831212882193*^9, 3.4348312181855307`*^9}}],

Cell[BoxData["5859"], "Output",
 CellChangeTimes->{
  3.434831219514971*^9, 3.4348325009000998`*^9, 3.434832781868763*^9, {
   3.4348328176391363`*^9, 3.434832841332365*^9}, 3.4348328919141693`*^9, 
   3.434833157768956*^9, 3.434833218637692*^9, 3.4348359458733463`*^9, 
   3.434836438399084*^9, 3.434838350979312*^9, {3.4348384005506144`*^9, 
   3.4348384126413*^9}, 3.434838552719667*^9, 3.434838666177204*^9, 
   3.434838875236762*^9, 3.4350009442650003`*^9, 3.435001204414*^9, 
   3.435001359049*^9, 3.435002008877*^9, 3.435003411467*^9, 3.435004073208*^9,
    3.435007334027*^9, 3.4350633487196627`*^9, 3.435063488088663*^9, 
   3.4350636873396626`*^9, 3.435064767157663*^9, 3.4350656311886625`*^9, 
   3.435092442281*^9, 3.435092515533*^9, 3.4350927977679996`*^9, 
   3.435092885925*^9, 3.435093216855*^9, 3.435094216263*^9, 3.435095358325*^9,
    3.4361171894375*^9, 3.43611731021875*^9, 3.436119504015625*^9, 
   3.43612127025*^9, 3.43612141590625*^9, 3.4361214905*^9, 
   3.436121587015625*^9, 3.43612170696875*^9, 3.436121790234375*^9, {
   3.436121869625*^9, 3.436121890671875*^9}, {3.436121951109375*^9, 
   3.43612196153125*^9}, 3.436122098484375*^9, 3.4361243713125*^9, 
   3.43612456453125*^9, 3.436124800203125*^9, 3.43612514275*^9, 
   3.436126306734375*^9, 3.436126821328125*^9, 3.436128309484375*^9, 
   3.436129062984375*^9, {3.43612940521875*^9, 3.436129424*^9}, 
   3.43612969409375*^9, 3.43613064521875*^9, 3.436131067046875*^9, 
   3.43613146646875*^9, 3.4361319544375*^9, 3.436132191609375*^9, 
   3.4361324896875*^9, 3.436132581953125*^9, 3.436132832671875*^9, 
   3.43613287784375*^9, 3.43613526203125*^9, 3.43613621603125*^9, 
   3.4361376103125*^9, 3.436184605390625*^9, 3.436189416375*^9, 
   3.436190856625*^9, 3.436191946546875*^9, 3.43619309715625*^9, 
   3.436194355*^9, 3.436196138328125*^9, 3.4361984555625*^9, 
   3.436202322734375*^9, 3.4362060134375*^9, 3.436565368536625*^9, 
   3.4366190068335*^9, 3.43716263888025*^9, {3.43723108163025*^9, 
   3.437231103208375*^9}, 3.43724472044275*^9, 3.437244757770875*^9, 
   3.437255026645875*^9, 3.43725507163025*^9, {3.43725510325525*^9, 
   3.437255167958375*^9}, 3.437327579840219*^9, 3.437331074896521*^9, 
   3.437395742663178*^9, 3.437399056669751*^9, 3.4373991152230663`*^9, 
   3.437408654660651*^9, 3.437409218358788*^9, 3.437412580628334*^9, 
   3.43741293489589*^9, 3.4374133506660624`*^9, 3.437413406473846*^9, 
   3.4374284457604303`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "EVB", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Alpha", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"AlphaMultiplier", "\[Rule]", "1.1`"}], ",", 
   RowBox[{"AlphaThreshold", "\[Rule]", "15"}], ",", 
   RowBox[{"AverageAlpha", "\[Rule]", "False"}], ",", 
   RowBox[{"CheckTS", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotIRC", "\[Rule]", "True"}], ",", 
   RowBox[{"RepulsivePotential", "\[Rule]", "True"}], ",", 
   RowBox[{"ReverseIRC", "\[Rule]", "False"}], ",", 
   RowBox[{"ScaleFactor", "\[Rule]", "1"}], ",", 
   RowBox[{"StartGuess", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"UseReactantAndProduct", "\[Rule]", "True"}], ",", 
   RowBox[{"V11Coord", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"V22Coord", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"V12Coordinates", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"V12CoordinateTolerance", "\[Rule]", "0"}], ",", 
   RowBox[{"DebugPrint", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxIterations", "\[Rule]", "1000"}], ",", 
   RowBox[{"ResidualPlot", "\[Rule]", "True"}], ",", 
   RowBox[{"Tolerance", "\[Rule]", "1.`*^-9"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4215935277903347`*^9, 3.421593964325211*^9, 3.4215940523609123`*^9, 
   3.421594273970414*^9, 3.421595104101989*^9, 3.42159536780268*^9, 
   3.4215956432313433`*^9, 3.421602350974502*^9, 3.435092442302*^9, 
   3.435092515552*^9, 3.435092797793*^9, 3.435092885948*^9, 3.435093216881*^9,
    3.436116983828125*^9, 3.436117189484375*^9, 3.43611731025*^9, 
   3.436119504640625*^9, 3.4361212703125*^9, 3.436121415953125*^9, 
   3.436121490546875*^9, 3.436121587078125*^9, 3.436121707015625*^9, 
   3.436121790296875*^9, {3.436121869671875*^9, 3.436121890734375*^9}, {
   3.43612195115625*^9, 3.436121961578125*^9}, 3.436122098546875*^9, 
   3.436124371359375*^9, 3.436124565109375*^9, 3.436124802140625*^9, 
   3.43612514359375*^9, 3.436126307640625*^9, 3.436126821375*^9, 
   3.436128311515625*^9, 3.436129063265625*^9, {3.436129405578125*^9, 
   3.4361294243125*^9}, 3.43612969484375*^9, 3.436130645296875*^9, 
   3.4361310675625*^9, 3.436131466796875*^9, 3.43613195471875*^9, 
   3.436132191671875*^9, 3.43613248975*^9, 3.436132582015625*^9, 
   3.43613283271875*^9, 3.43613287790625*^9, 3.436135262109375*^9, 
   3.436136216921875*^9, 3.436137610390625*^9, 3.436184605734375*^9, 
   3.43618941640625*^9, 3.436190856671875*^9, 3.436191946578125*^9, 
   3.4361930971875*^9, 3.436194355046875*^9, 3.436196138375*^9, 
   3.43619845559375*^9, 3.43620232278125*^9, 3.43620601346875*^9, 
   3.43656536880225*^9, 3.43661900686475*^9, 3.437162639349*^9, {
   3.43723108169275*^9, 3.437231103349*^9}, 3.437244720489625*^9, 
   3.43724475781775*^9, 3.437255026677125*^9, 3.437255071677125*^9, {
   3.437255103302125*^9, 3.437255167989625*^9}, 3.437327580324514*^9, 
   3.43733107510572*^9, 3.43739574278617*^9, 3.437399056796362*^9, 
   3.437399115361348*^9, 3.4374086548825903`*^9, 3.437412582360216*^9, 
   3.437412935301013*^9, 3.4374133510179977`*^9, 3.437413406590838*^9, 
   3.437428445888155*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EVB", "[", 
  RowBox[{"iReactant", ",", "iProduct", ",", "iTS", ",", 
   RowBox[{"Take", "[", 
    RowBox[{"iOtherPoints", ",", 
     RowBox[{"Max", "[", 
      RowBox[{"0", ",", 
       RowBox[{"nDG", "-", "3"}]}], "]"}]}], "]"}], ",", "IRCFile", ",", 
   RowBox[{"V11Coord", "\[Rule]", "icoordV11"}], ",", 
   RowBox[{"Alpha", "\[Rule]", "alpha"}], ",", 
   RowBox[{"StartGuess", "\[Rule]", "Guess"}], ",", 
   RowBox[{"V22Coord", "\[Rule]", "icoordV22"}], ",", 
   RowBox[{"RepulsivePotential", "\[Rule]", "False"}], ",", 
   RowBox[{"UseReactantAndProduct", "\[Rule]", "UseRP"}], ",", 
   RowBox[{"DebugPrint", "\[Rule]", "iDebug"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.421593949369843*^9, 3.421593957399342*^9}, {
   3.421594017417639*^9, 3.42159401760992*^9}, {3.421594157739234*^9, 
   3.4215941654572268`*^9}, {3.42159422930584*^9, 3.421594230713252*^9}, {
   3.435092872921*^9, 3.4350928796949997`*^9}, {3.435093187828*^9, 
   3.4350932000889997`*^9}, {3.435093526078*^9, 3.435093532113*^9}, {
   3.435094206326*^9, 3.435094207837*^9}, 3.435095364466*^9, 
   3.43611698121875*^9, {3.4361171796875*^9, 3.4361171805*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "3", "\[InvisibleSpace]", "\<\" points will be used in the EVB PES \
fit.\"\>"}],
  SequenceForm[3, " points will be used in the EVB PES fit."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.4374284460483627`*^9}],

Cell[BoxData["\<\"The following files were passed to EVB:\"\>"], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428446181282*^9}],

Cell[BoxData["\<\"claisen_R_61.fchk\"\>"], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428446297204*^9}],

Cell[BoxData["\<\"claisen_P_61.fchk\"\>"], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428446402272*^9}],

Cell[BoxData["\<\"claisen_TS_61.fchk\"\>"], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.4374284465209846`*^9}],

Cell[BoxData["\<\"claisen_TS_irc_neg_calcall.fchk\"\>"], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.4374284466627903`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The alpha multiplier was set to \"\>", "\[InvisibleSpace]", 
   "1.1`", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["The alpha multiplier was set to ", 1.1, "."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428446795257*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The molecular system contains \"\>", "\[InvisibleSpace]", "14",
    "\[InvisibleSpace]", "\<\" atoms.\"\>"}],
  SequenceForm["The molecular system contains ", 14, " atoms."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428446912929*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Read in \"\>", "\[InvisibleSpace]", "61", 
   "\[InvisibleSpace]", "\<\" internal coordinates.\"\>"}],
  SequenceForm["Read in ", 61, " internal coordinates."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428447019219*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "0", ",", "0"}], "}"}]},
     {"2", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6", ",", "0", ",", "0"}], "}"}]},
     {"3", 
      RowBox[{"{", 
       RowBox[{"1", ",", "7", ",", "0", ",", "0"}], "}"}]},
     {"4", 
      RowBox[{"{", 
       RowBox[{"1", ",", "8", ",", "0", ",", "0"}], "}"}]},
     {"5", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "0", ",", "0"}], "}"}]},
     {"6", 
      RowBox[{"{", 
       RowBox[{"2", ",", "9", ",", "0", ",", "0"}], "}"}]},
     {"7", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4", ",", "0", ",", "0"}], "}"}]},
     {"8", 
      RowBox[{"{", 
       RowBox[{"3", ",", "10", ",", "0", ",", "0"}], "}"}]},
     {"9", 
      RowBox[{"{", 
       RowBox[{"3", ",", "11", ",", "0", ",", "0"}], "}"}]},
     {"10", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5", ",", "0", ",", "0"}], "}"}]},
     {"11", 
      RowBox[{"{", 
       RowBox[{"5", ",", "6", ",", "0", ",", "0"}], "}"}]},
     {"12", 
      RowBox[{"{", 
       RowBox[{"5", ",", "14", ",", "0", ",", "0"}], "}"}]},
     {"13", 
      RowBox[{"{", 
       RowBox[{"6", ",", "12", ",", "0", ",", "0"}], "}"}]},
     {"14", 
      RowBox[{"{", 
       RowBox[{"6", ",", "13", ",", "0", ",", "0"}], "}"}]},
     {"15", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "6", ",", "0"}], "}"}]},
     {"16", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "7", ",", "0"}], "}"}]},
     {"17", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "8", ",", "0"}], "}"}]},
     {"18", 
      RowBox[{"{", 
       RowBox[{"6", ",", "1", ",", "7", ",", "0"}], "}"}]},
     {"19", 
      RowBox[{"{", 
       RowBox[{"6", ",", "1", ",", "8", ",", "0"}], "}"}]},
     {"20", 
      RowBox[{"{", 
       RowBox[{"7", ",", "1", ",", "8", ",", "0"}], "}"}]},
     {"21", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "0"}], "}"}]},
     {"22", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "9", ",", "0"}], "}"}]},
     {"23", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2", ",", "9", ",", "0"}], "}"}]},
     {"24", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "4", ",", "0"}], "}"}]},
     {"25", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "10", ",", "0"}], "}"}]},
     {"26", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "11", ",", "0"}], "}"}]},
     {"27", 
      RowBox[{"{", 
       RowBox[{"4", ",", "3", ",", "10", ",", "0"}], "}"}]},
     {"28", 
      RowBox[{"{", 
       RowBox[{"4", ",", "3", ",", "11", ",", "0"}], "}"}]},
     {"29", 
      RowBox[{"{", 
       RowBox[{"10", ",", "3", ",", "11", ",", "0"}], "}"}]},
     {"30", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4", ",", "5", ",", "0"}], "}"}]},
     {"31", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5", ",", "6", ",", "0"}], "}"}]},
     {"32", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5", ",", "14", ",", "0"}], "}"}]},
     {"33", 
      RowBox[{"{", 
       RowBox[{"6", ",", "5", ",", "14", ",", "0"}], "}"}]},
     {"34", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6", ",", "5", ",", "0"}], "}"}]},
     {"35", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6", ",", "12", ",", "0"}], "}"}]},
     {"36", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6", ",", "13", ",", "0"}], "}"}]},
     {"37", 
      RowBox[{"{", 
       RowBox[{"5", ",", "6", ",", "12", ",", "0"}], "}"}]},
     {"38", 
      RowBox[{"{", 
       RowBox[{"5", ",", "6", ",", "13", ",", "0"}], "}"}]},
     {"39", 
      RowBox[{"{", 
       RowBox[{"12", ",", "6", ",", "13", ",", "0"}], "}"}]},
     {"40", 
      RowBox[{"{", 
       RowBox[{"6", ",", "1", ",", "2", ",", "3"}], "}"}]},
     {"41", 
      RowBox[{"{", 
       RowBox[{"6", ",", "1", ",", "2", ",", "9"}], "}"}]},
     {"42", 
      RowBox[{"{", 
       RowBox[{"7", ",", "1", ",", "2", ",", "3"}], "}"}]},
     {"43", 
      RowBox[{"{", 
       RowBox[{"8", ",", "1", ",", "2", ",", "9"}], "}"}]},
     {"44", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "6", ",", "5"}], "}"}]},
     {"45", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "6", ",", "13"}], "}"}]},
     {"46", 
      RowBox[{"{", 
       RowBox[{"7", ",", "1", ",", "6", ",", "5"}], "}"}]},
     {"47", 
      RowBox[{"{", 
       RowBox[{"7", ",", "1", ",", "6", ",", "12"}], "}"}]},
     {"48", 
      RowBox[{"{", 
       RowBox[{"8", ",", "1", ",", "6", ",", "12"}], "}"}]},
     {"49", 
      RowBox[{"{", 
       RowBox[{"8", ",", "1", ",", "6", ",", "13"}], "}"}]},
     {"50", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]},
     {"51", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "11"}], "}"}]},
     {"52", 
      RowBox[{"{", 
       RowBox[{"9", ",", "2", ",", "3", ",", "4"}], "}"}]},
     {"53", 
      RowBox[{"{", 
       RowBox[{"9", ",", "2", ",", "3", ",", "10"}], "}"}]},
     {"54", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "4", ",", "5"}], "}"}]},
     {"55", 
      RowBox[{"{", 
       RowBox[{"11", ",", "3", ",", "4", ",", "5"}], "}"}]},
     {"56", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4", ",", "5", ",", "6"}], "}"}]},
     {"57", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4", ",", "5", ",", "14"}], "}"}]},
     {"58", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5", ",", "6", ",", "1"}], "}"}]},
     {"59", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5", ",", "6", ",", "13"}], "}"}]},
     {"60", 
      RowBox[{"{", 
       RowBox[{"14", ",", "5", ",", "6", ",", "1"}], "}"}]},
     {"61", 
      RowBox[{"{", 
       RowBox[{"14", ",", "5", ",", "6", ",", "12"}], "}"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428447118932*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ab initio energies: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "269.7784374817896`"}], ",", 
     RowBox[{"-", "269.8150226875673`"}], ",", 
     RowBox[{"-", "269.740664506533`"}]}], "}"}]}],
  SequenceForm[
  "Ab initio energies: ", {-269.7784374817896, -269.8150226875673, \
-269.740664506533}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.4374284472172337`*^9}],

Cell[BoxData["\<\"Cartesian Coordinates:\"\>"], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428447309263*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"4.3416115`", 
      RowBox[{"-", "1.69335449`"}], "0.203282301`", "2.82456889`", 
      RowBox[{"-", "0.0247882335`"}], 
      RowBox[{"-", "0.953452124`"}], "1.2586444`", "1.87883106`", 
      "0.444822724`", 
      RowBox[{"-", "1.36303247`"}], "1.7049777`", 
      RowBox[{"-", "0.203443805`"}], 
      RowBox[{"-", "2.49571725`"}], 
      RowBox[{"-", "0.448876958`"}], "0.6494141280000001`", 
      RowBox[{"-", "4.65794442`"}], 
      RowBox[{"-", "1.31349514`"}], 
      RowBox[{"-", "0.34018763100000005`"}], "4.4922002`", 
      RowBox[{"-", "1.74781674`"}], "2.25158271`", "5.47210323`", 
      RowBox[{"-", "3.03237718`"}], 
      RowBox[{"-", "0.861588613`"}], "2.67363035`", "0.00167813175`", 
      RowBox[{"-", "3.00521506`"}], "1.79478936`", "3.80592968`", 
      RowBox[{"-", "0.0684720378`"}], "1.49808797`", "1.65031632`", 
      "2.49583735`", 
      RowBox[{"-", "5.54579244`"}], 
      RowBox[{"-", "2.96189486`"}], "0.482491378`", 
      RowBox[{"-", "5.5458816`"}], 
      RowBox[{"-", "0.373625134`"}], 
      RowBox[{"-", "1.927907`"}], 
      RowBox[{"-", "1.56185605`"}], 
      RowBox[{"-", "1.37192927`"}], "2.23754532`"},
     {
      RowBox[{"-", "1.29772308`"}], "2.08027245`", "0.361154805`", 
      RowBox[{"-", "2.74512649`"}], 
      RowBox[{"-", "0.0107102686`"}], 
      RowBox[{"-", "0.902525801`"}], 
      RowBox[{"-", "4.02298396`"}], 
      RowBox[{"-", "1.81404511`"}], "0.34012301200000006`", "3.98074889`", 
      RowBox[{"-", "1.93421061`"}], 
      RowBox[{"-", "0.476329349`"}], "2.67330157`", 
      RowBox[{"-", "0.49501146800000007`"}], "0.7446822590000001`", 
      "1.54235232`", "1.92771642`", 
      RowBox[{"-", "0.250972664`"}], 
      RowBox[{"-", "1.57933202`"}], "1.9819817`", "2.41280029`", 
      RowBox[{"-", "2.01333289`"}], "3.92082722`", 
      RowBox[{"-", "0.26533201300000003`"}], 
      RowBox[{"-", "2.68740423`"}], 
      RowBox[{"-", "0.054489420700000006`"}], 
      RowBox[{"-", "2.96210471`"}], 
      RowBox[{"-", "5.01027349`"}], 
      RowBox[{"-", "3.30556785`"}], 
      RowBox[{"-", "0.6625671750000001`"}], 
      RowBox[{"-", "4.10879433`"}], 
      RowBox[{"-", "1.83459997`"}], "2.39265623`", "2.53524614`", 
      "3.50227129`", "0.6690489780000001`", "1.88816067`", "2.04085208`", 
      RowBox[{"-", "2.28623332`"}], "2.23081682`", 
      RowBox[{"-", "0.9069223750000002`"}], "2.75759685`"},
     {
      RowBox[{"-", "0.8377511350000001`"}], "2.80437015`", "0.593584949`", 
      RowBox[{"-", "2.41510995`"}], "1.05968528`", 
      RowBox[{"-", "0.566764884`"}], 
      RowBox[{"-", "2.50709179`"}], 
      RowBox[{"-", "1.43231293`"}], "0.37499299`", "0.548783942`", 
      RowBox[{"-", "2.61995266`"}], 
      RowBox[{"-", "0.520467239`"}], "2.2558725`", 
      RowBox[{"-", "1.17156827`"}], "0.497159602`", "2.85021947`", 
      "1.16020662`", 
      RowBox[{"-", "0.53694304`"}], 
      RowBox[{"-", "0.473651459`"}], "2.65999912`", "2.60951948`", 
      RowBox[{"-", "0.590093631`"}], "4.6753954`", 
      RowBox[{"-", "0.220316273`"}], 
      RowBox[{"-", "2.98036466`"}], "1.38079221`", 
      RowBox[{"-", "2.51686106`"}], 
      RowBox[{"-", "3.68223239`"}], 
      RowBox[{"-", "2.8158588`"}], 
      RowBox[{"-", "0.5807222320000001`"}], 
      RowBox[{"-", "2.35220005`"}], 
      RowBox[{"-", "1.70436993`"}], "2.40776822`", "4.29371225`", 
      "2.31425528`", "0.364340326`", "2.47633621`", "1.50242619`", 
      RowBox[{"-", "2.52206081`"}], "2.84138759`", 
      RowBox[{"-", "1.57530328`"}], "2.44989255`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428447441934*^9}],

Cell[BoxData["\<\"Internal Coordinates:\"\>"], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428447536622*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"2.5344755202735962`", "9.023949215835467`", "2.0545504760779965`", 
      "2.0505958596018927`", "2.8339122205030667`", "2.0574775957201132`", 
      "2.706226911051251`", "2.0650985501497563`", "2.0775498082302457`", 
      "2.5786491332697783`", "2.5302376522269774`", "2.060651109372309`", 
      "2.0450663792070958`", "2.047593919336193`", "0.8603866379524163`", 
      "2.1133619537751147`", "2.1210168759883854`", "1.705457946714875`", 
      "2.148404164942669`", "2.048793080679967`", "2.150510869282997`", 
      "2.1030912247772573`", "2.0295822883147454`", "1.9540665708266962`", 
      "1.9398595088728323`", "1.9278722485902087`", "1.8254587863332161`", 
      "1.91885401436536`", "1.8945235637010505`", "1.9822733400825174`", 
      "2.1310892473104084`", "2.0152705675431615`", "2.1360518915710363`", 
      "0.5327464987411921`", "1.9549891607616527`", "2.0926614658593636`", 
      "2.081851946696049`", "2.1141338996228534`", "2.087069699527536`", 
      "1.2625858737789137`", 
      RowBox[{"-", "1.8774900467818478`"}], "0.008945114082117544`", 
      "0.01617060687547944`", 
      RowBox[{"-", "1.316862477494325`"}], "0.45418637368784964`", 
      "0.8613783741117268`", 
      RowBox[{"-", "1.0702189878105788`"}], "1.198196144940477`", 
      RowBox[{"-", "1.3823429491346295`"}], 
      RowBox[{"-", "2.1769507603567937`"}], 
      RowBox[{"-", "0.032223090143342174`"}], "0.9631842775019517`", 
      RowBox[{"-", "1.071235635833437`"}], "1.2041407720358595`", 
      RowBox[{"-", "0.9456905919021401`"}], 
      RowBox[{"-", "2.7977330306125325`"}], "0.3851897382461457`", 
      "1.745532353370138`", "0.05217786827639961`", 
      RowBox[{"-", "1.4402497673359662`"}], "0.02537489724820538`"},
     {"2.839731331436832`", "2.909295732351537`", "2.0732134146643877`", 
      "2.0717685668688373`", "2.535569430382902`", "2.060852676892682`", 
      "8.046165157349298`", "2.0505531719735592`", "2.054429004093982`", 
      "2.2959925983720995`", "2.853065956311322`", "2.1017346407072472`", 
      "2.076415420426097`", "2.0675272743920234`", "1.9447825939964558`", 
      "1.9137052166228694`", "1.9214756459384257`", "1.9159373265571966`", 
      "1.8966868865838136`", "1.8696736457825522`", "2.168172015731081`", 
      "2.033189216018944`", "2.081499713360992`", "0.9998568386740626`", 
      "2.118028329197236`", "2.1150741669964503`", "2.002539668954768`", 
      "1.7140620548926346`", "2.050082643603102`", "0.8895414388651077`", 
      "2.180256714548637`", "2.101759881453584`", "2.001157731498798`", 
      "1.9369945898931793`", "1.9111388536841518`", "1.9471463741810462`", 
      "1.8752299973130822`", "1.900430826640859`", "1.890930316422258`", 
      "2.046261533459399`", 
      RowBox[{"-", "1.067676377896206`"}], 
      RowBox[{"-", "0.0784626240449612`"}], "1.038040919869481`", 
      RowBox[{"-", "1.0941863986938005`"}], "1.0285333302217567`", 
      "1.02924296200607`", 
      RowBox[{"-", "1.0380851500407162`"}], "1.001475365281795`", 
      RowBox[{"-", "1.0916621009354486`"}], 
      RowBox[{"-", "1.35805697106897`"}], "0.021166221151134663`", 
      "1.7551647616526531`", 
      RowBox[{"-", "0.00784234683288158`"}], "1.1971944276768847`", 
      RowBox[{"-", "0.9311704350082725`"}], 
      RowBox[{"-", "1.5533946505531548`"}], "1.5935107344520483`", 
      "2.275051728010756`", "0.12520830308398442`", 
      RowBox[{"-", "0.8715818524077747`"}], "1.2173274696036782`"},
     {"2.6226699872092656`", "4.193148510443973`", "2.053631807711586`", 
      "2.0553600474364986`", "2.665600050790439`", "2.055601528341773`", 
      "3.398634084367092`", "2.051474150391597`", "2.0567405276482447`", 
      "2.459173250011847`", "2.61912022109984`", "2.0782193929232253`", 
      "2.0561642496133943`", "2.048803428093819`", "1.7201976672902872`", 
      "2.0876813683840925`", "2.097679581718083`", "1.6520489888537977`", 
      "1.715501057566946`", "2.016788462907217`", "2.0787044805924304`", 
      "2.072807699760161`", "2.0620316145783097`", "1.7747826593976057`", 
      "2.07792383068696`", "2.0603661011025083`", "1.7280837195448882`", 
      "1.717794089294982`", "1.998046377027632`", "1.8852746231873305`", 
      "2.115889821456549`", "2.060061914023401`", "2.071462609824967`", 
      "1.6138607745129827`", "1.8537549107727185`", "1.6060379373159441`", 
      "2.07822300288533`", "2.082716673785006`", "2.0477444262793494`", 
      "1.199665150764737`", 
      RowBox[{"-", "1.542767763939665`"}], 
      RowBox[{"-", "0.5520906268923956`"}], "0.2871894672470035`", 
      RowBox[{"-", "0.9675808154228986`"}], "1.1177512535605374`", 
      "1.1426525115220763`", 
      RowBox[{"-", "0.97388586782154`"}], "1.0628008859567808`", 
      RowBox[{"-", "1.0185139728957533`"}], 
      RowBox[{"-", "1.2246922153189874`"}], "0.6295877354116154`", 
      "1.5201955465377208`", 
      RowBox[{"-", "0.35311181164468847`"}], "1.0153941727925666`", 
      RowBox[{"-", "1.0976551365152347`"}], 
      RowBox[{"-", "1.368442696312769`"}], "1.4852378924269563`", 
      "1.2240085026083756`", 
      RowBox[{"-", "0.4114979588162509`"}], 
      RowBox[{"-", "1.6278435237838291`"}], "0.2938106450450125`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428447669001*^9}],

Cell[BoxData["\<\"Internal gradients:\"\>"], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.4374284477765102`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "3.85340851`*^-6"}], 
      RowBox[{"-", "3.3996655699999994`*^-7"}], "1.8541635`*^-6", 
      RowBox[{"-", "3.43491335`*^-7"}], 
      RowBox[{"-", "7.89775516`*^-6"}], "1.35813131`*^-6", "7.19737794`*^-6", 
      
      RowBox[{"-", "2.45198272`*^-6"}], 
      RowBox[{"-", "7.3791393`*^-7"}], 
      RowBox[{"-", "0.000015195133700000003`"}], 
      RowBox[{"-", "1.33196785`*^-6"}], 
      RowBox[{"-", "5.39285556`*^-7"}], 
      RowBox[{"-", "1.7762699099999997`*^-6"}], "1.4871487299999999`*^-6", 
      RowBox[{"-", "2.08327151`*^-6"}], "6.25928035`*^-7", "9.04954582`*^-7", 
      "1.5657348`*^-6", "3.0143555`*^-7", 
      RowBox[{"-", "1.52590096`*^-6"}], "3.35786263`*^-6", 
      RowBox[{"-", "2.8791841999999998`*^-6"}], 
      RowBox[{"-", "4.824590169999999`*^-7"}], "2.27606968`*^-6", 
      "1.55807825`*^-6", 
      RowBox[{"-", "1.89650192`*^-6"}], 
      RowBox[{"-", "3.3907873599999997`*^-6"}], "2.8101486699999997`*^-7", 
      "1.1388512799999999`*^-6", 
      RowBox[{"-", "5.230778789999999`*^-7"}], 
      RowBox[{"-", "3.17862892`*^-6"}], "2.97345317`*^-7", 
      "2.8814823199999997`*^-6", 
      RowBox[{"-", "7.91882566`*^-7"}], "3.2118348399999996`*^-6", 
      RowBox[{"-", "3.7445081199999997`*^-6"}], "3.33679207`*^-6", 
      RowBox[{"-", "3.7876230199999996`*^-6"}], "4.71135907`*^-7", 
      RowBox[{"-", "2.45157018`*^-7"}], "2.85559316`*^-6", 
      RowBox[{"-", "1.59675506`*^-7"}], "1.8845761599999998`*^-6", 
      "4.5963931`*^-7", 
      RowBox[{"-", "1.20292295`*^-6"}], "7.37743074`*^-7", 
      RowBox[{"-", "7.00817003`*^-7"}], 
      RowBox[{"-", "1.10299967`*^-6"}], 
      RowBox[{"-", "1.32700186`*^-6"}], "1.32072333`*^-6", "1.91919102`*^-6", 
      
      RowBox[{"-", "1.66129411`*^-6"}], "1.33224958`*^-7", "6.37134524`*^-8", 
      "7.100340169999999`*^-7", 
      RowBox[{"-", "6.64571663`*^-7"}], 
      RowBox[{"-", "7.45975017`*^-7"}], 
      RowBox[{"-", "8.213777699999999`*^-7"}], "8.272407380000001`*^-7", 
      RowBox[{"-", "8.088918409999999`*^-7"}], 
      RowBox[{"-", "5.26517111`*^-7"}]},
     {"7.25425268`*^-6", 
      RowBox[{"-", "0.000013945861600000001`"}], 
      RowBox[{"-", "3.62559134`*^-6"}], 
      RowBox[{"-", "9.222084609999998`*^-6"}], "5.26304487`*^-6", 
      RowBox[{"-", "3.18352995`*^-6"}], 
      RowBox[{"-", "5.08315813`*^-6"}], 
      RowBox[{"-", "4.4409415900000004`*^-6"}], 
      RowBox[{"-", "2.23677809`*^-6"}], 
      RowBox[{"-", "1.92519043`*^-6"}], "6.33459542`*^-6", "8.01554679`*^-7", 
      "2.6093704299999996`*^-6", 
      RowBox[{"-", "1.22314899`*^-6"}], 
      RowBox[{"-", "8.665375049999999`*^-6"}], "5.0419704`*^-6", 
      "5.147055749999999`*^-6", "3.14840394`*^-6", 
      RowBox[{"-", "2.5321728`*^-6"}], 
      RowBox[{"-", "1.90977904`*^-6"}], 
      RowBox[{"-", "4.244570829999999`*^-6"}], "4.40337654`*^-6", 
      "2.5868812600000003`*^-9", "2.2401840399999997`*^-7", 
      RowBox[{"-", "3.95792124`*^-6"}], 
      RowBox[{"-", "1.4194621599999999`*^-6"}], "2.68583453`*^-6", 
      "5.2066587`*^-6", "5.369904139999999`*^-6", "2.00183549`*^-7", 
      "2.0826488099999996`*^-6", "2.78175498`*^-6", 
      RowBox[{"-", "4.85595641`*^-6"}], "4.910440229999999`*^-6", 
      "5.40311564`*^-7", "1.27980528`*^-6", 
      RowBox[{"-", "7.17843872`*^-6"}], "3.16762013`*^-6", 
      RowBox[{"-", "3.23206742`*^-6"}], "4.44873328`*^-6", 
      RowBox[{"-", "2.44075458`*^-6"}], "2.7760634799999996`*^-6", 
      RowBox[{"-", "7.86629981`*^-6"}], 
      RowBox[{"-", "7.3026866`*^-6"}], "1.0769061`*^-6", 
      RowBox[{"-", "4.54188071`*^-6"}], "9.70437962`*^-7", 
      RowBox[{"-", "1.01232235`*^-6"}], "1.85495168`*^-6", 
      RowBox[{"-", "1.7696230299999999`*^-6"}], "6.7843862`*^-6", 
      "5.36062109`*^-6", 
      RowBox[{"-", "3.29633585`*^-7"}], "1.83109464`*^-7", "5.42598811`*^-6", 
      "5.13617685`*^-6", "3.10658405`*^-6", "3.50537898`*^-6", 
      RowBox[{"-", "3.5025577899999997`*^-6"}], "5.45060547`*^-6", 
      "4.503670739999999`*^-6"},
     {
      RowBox[{"-", "2.0372461400000004`*^-8"}], 
      RowBox[{"-", "2.9120805500000002`*^-8"}], 
      RowBox[{"-", "4.9909443`*^-10"}], 
      RowBox[{"-", "1.52829153`*^-9"}], 
      RowBox[{"-", "3.61171499`*^-8"}], "3.28714185`*^-10", 
      RowBox[{"-", "3.92177337`*^-8"}], 
      RowBox[{"-", "5.47123736`*^-10"}], 
      RowBox[{"-", "1.83747404`*^-9"}], 
      RowBox[{"-", "4.8829233`*^-8"}], 
      RowBox[{"-", "4.89040488`*^-8"}], 
      RowBox[{"-", "1.43414903`*^-9"}], 
      RowBox[{"-", "5.33342711`*^-9"}], 
      RowBox[{"-", "5.856646170000001`*^-9"}], 
      RowBox[{"-", "4.87285703`*^-9"}], "2.37128`*^-9", 
      RowBox[{"-", "3.2797330900000005`*^-9"}], 
      RowBox[{"-", "1.69227453`*^-10"}], 
      RowBox[{"-", "6.047284000000001`*^-9"}], "5.767987570000001`*^-9", 
      RowBox[{"-", "1.27021792`*^-8"}], "1.3483790600000002`*^-9", 
      "5.79439775`*^-9", "3.37765804`*^-9", "1.1480821`*^-9", 
      "1.61077508`*^-8", 
      RowBox[{"-", "1.85281533`*^-8"}], 
      RowBox[{"-", "1.0607706299999999`*^-8"}], 
      RowBox[{"-", "3.19717774`*^-9"}], 
      RowBox[{"-", "8.095862560000002`*^-9"}], 
      RowBox[{"-", "1.14212786`*^-8"}], "1.3398963100000001`*^-8", 
      "1.21351712`*^-9", "2.1992825500000003`*^-9", 
      RowBox[{"-", "2.10445216`*^-10"}], "1.4115018800000002`*^-9", 
      "3.84630774`*^-9", 
      RowBox[{"-", "9.24370124`*^-9"}], "3.50403634`*^-9", 
      RowBox[{"-", "1.1687212`*^-8"}], "2.1660633100000003`*^-9", 
      RowBox[{"-", "9.147157730000001`*^-9"}], 
      RowBox[{"-", "9.22047817`*^-9"}], "5.12359601`*^-10", 
      RowBox[{"-", "8.51867502`*^-9"}], "2.01063395`*^-9", 
      RowBox[{"-", "2.8469193900000003`*^-9"}], "2.02982684`*^-9", 
      RowBox[{"-", "2.1436544400000005`*^-9"}], 
      RowBox[{"-", "7.2143537400000005`*^-9"}], 
      RowBox[{"-", "1.1811641100000002`*^-8"}], 
      RowBox[{"-", "2.19612769`*^-8"}], 
      RowBox[{"-", "2.19882148`*^-9"}], "2.98084956`*^-8", "1.51792014`*^-8", 
      
      RowBox[{"-", "2.44139724`*^-8"}], 
      RowBox[{"-", "1.15451299`*^-8"}], "1.2338458000000001`*^-8", 
      "1.02067602`*^-8", 
      RowBox[{"-", "2.54582812`*^-9"}], 
      RowBox[{"-", "4.96302413`*^-10"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.4374284478775387`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Read in \"\>", "\[InvisibleSpace]", "32", 
   "\[InvisibleSpace]", "\<\" forward and \"\>", "\[InvisibleSpace]", "33", 
   "\[InvisibleSpace]", "\<\" reverse IRC steps.\"\>"}],
  SequenceForm["Read in ", 32, " forward and ", 33, " reverse IRC steps."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428448605782*^9}],

Cell[BoxData["\<\"\\!\\(\\*SubscriptBox[\\\"V\\\", \\\"11\\\"]\\)(Blue), \
\\!\\(\\*SubscriptBox[\\\"V\\\", \\\"22\\\"]\\)(Green), and Electronic Energy \
(Red) along the IRC path:\"\>"], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428453395589*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.005], LineBox[CompressedData["
1:eJwBMQTO+1JvYiFlAAAAAgAAAEIAAAACwDAOAAoQ+vpAWAO7wUZJKsAvdrJ2
CXGZQFgGFftJAJ/ALvjd6wJB+UBYCPFBudInwC35FwoHwL9AWBOySuqPNsAs
+UODDI9aQFgkf+lGw3HAK/lqty3/FkBYOq4MO0GxwCr5kCL4Uo1AWFaSvBGM
BcAp+bVcbb8gQFh3geg2nk7AKPnbGL/qZ0BYnXuQqqGTwCf6AaUbrdxAWMgp
rSQTwsAm+ijwuhHgQFj3YTl94cnAJfpQWotm0UBZKvcxk5yqwCT6drtIQApA
WWLAkUBaWcAj+psEJ9fgQFmevViEGtXAIvq9Def1HEBZ3u2HXt4ewCH63n+n
qv9AWiMmGavjLcAg+wM89lWHQFprvRe0rBDAH/Zhe3AN2kBauV6SDDzpwB32
1KGtZFJAWw3jtkczGsAb91XHh757QFtsJ8rWNyXAGffLINAvLUBb2QpH40/3
wBf4Ixk0r19AXFpsvnWFv8AV+GOKk+0yQFz3B9RK2LbAE/icYR8pvEBdtuxQ
R/VrwBH41P1H6c9AXqLXCeS1lsAP8hlKU+EpQF/FXgYswzHAC/KNVLzFxEBg
lOGtX48zwAfzM2DVgtRAYW26EK/YtcAD9PsvCtp6QGJzWkRE7Ma///QCyV4C
akBjr5a6hWLMv/f70KDB1vpAZSvt3Y47lr/v/M/Lc6AlQGa7l90amBO/3/6r
Bztu0kBn8kjKngMMAAAAAAAAAABAaGc8Do/Ibj/f/cs/4na3QGfy31kepqg/
7/ykmPwP3EBmq8xXmxMOP/f9TtrZf+RAZLGaFQQXrD///GD8RDO3QGIlTT+R
ZNdAA/3I6LyXdUBeeCjta2xsQAf9V9dXakpAWIMaBh9JjEAL/DGJj+E0QFMe
C/3jcTtAD/euT4kqNkBNuhAudN+bQBH4XbluoR1AR39wk7WGZ0AT9zsRzt93
QEK7hxEvru9AFfbeIFxA9EA9+CFKevaXQBf2pP6nkFJAOA/XnhidJ0AZ9nLD
7NRUQDNm0LKMYM5AG/ZBRRm6kUAvbPN3DgA3QB32FGNkU2dAKYticGnQBUAf
9exMbu51QCTRjeaBiHdAIPrfMtXrL0Ag/u+iMQ07QCH6vzHZluBAG8OVse05
d0Ai+pTkKDMlQBajl1C1Xj5AI/pkm7X+f0ASYA4r4nz5QCT6NUzo5t9ADZEr
NEEa4kAl+gyJez5lQAdps3HgrV5AJvnrus6dh0ACJBFwesptQCf50D5xVNc/
+yqCFrFXLUAo+bUV9uJKP/NlAnJ1WTxAKfmTs6aLGj/p2cXWYDsQQCr5Y+0P
YnQ/3wiOAwt+RkAr+R15jYqXP88mIZoREr9ALPjAGWAjVj+1TFAqOkW3QC14
ZD5t+dg/o75szehQAEAt1GqFr9fJP5H6xzi8RFRALikyrqj1Vz9dk5cFlHjl
a434VA==
     "]]}, 
   {RGBColor[0, 0, 1], Thickness[0.005], 
    LineBox[{{-16.0546881, 96.0572846776419}, {-15.7318303, 
     96.08970397974085}, {-15.486068099999999`, 
     96.13975843098714}, {-14.9865039, 96.32016880122346}, {-14.4868432, 
     96.6210877948269}, {-13.987142299999999`, 
     97.06441641977902}, {-13.4874278, 97.67463074662666}, {-12.9877118, 
     98.47843379765698}, {-12.487999700000001`, 
     99.50467442874164}, {-11.988293800000001`, 
     100.78447843547997`}, {-11.488593600000002`, 
     102.35138348203647`}, {-10.9888943, 
     104.2411281900253}, {-10.489187099999999`, 
     106.49070532443604`}, {-9.98946393, 109.13640473001368`}, {-9.48972362, 
     112.21065447774218`}, {-8.98997878, 115.73741201718362`}, {-8.49025908, 
     119.72554786157}, {-7.99060624, 124.159838522723}, {-7.4910455, 
     128.99210288028328`}, {-6.99153816, 134.1424693314097}, {-6.49198581, 
     139.5247389315881}, {-5.99232139, 145.09301775313807`}, {-5.49256722, 
     150.88046992536363`}, {-4.99278404, 157.0041999921483}, {-4.49299999, 
     163.64026483663665`}, {-3.9932123, 170.99064835972626`}, {-3.49343363, 
     179.25808275746482`}, {-2.99375034, 
     188.6350309750711}, {-2.5943926525871226`, 197.2273767596721}}]}, 
   {RGBColor[0., 0.75, 0.], Thickness[0.005], 
    LineBox[{{2.0024162031963457`, 197.2273767596721}, {2.49891836, 
     133.81671317921302`}, {2.9987027, 86.76116132362465}, {3.49814136, 
     56.60894779197281}, {3.99593794, 40.89723742488192}, {4.49254503, 
     33.53804765023764}, {4.99143627, 28.902053520430464`}, {5.49108172, 
     25.230992304060965`}, {5.99086378, 22.11293866319875}, {6.49067217, 
     19.35795955041798}, {6.99048336, 16.862683211354415`}, {7.49031215, 
     14.580278523372167`}, {7.99015922, 12.496941159708758`}, {8.48998412, 
     10.608389887923659`}, {8.98973995, 8.906298187271862}, {9.4894172, 
     7.37790309458705}, {9.98904883, 6.011159736390241}, {10.4886879, 
     4.797865718759997}, {10.9883769, 3.7334025859606306`}, {11.4881266, 
     2.8149154834332837`}, {11.9879169, 2.0395272890597544`}, {12.4877097, 
     1.4030921920352837`}, {12.987455, 0.899372369099167}, {13.4870905, 
     0.5195468275796146}, {13.986552999999999`, 0.2523209839213509}, {
     14.4858406, 0.08528991607213299}, {14.735139799999999`, 
     0.03633066925050948}, {14.914875199999999`, 0.013771955345094277`}, {
     15.0804648, 0.0025286919146076023`}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Reaction coordinate\"", TraditionalForm], 
    FormBox[
     FractionBox[
     "\"Energy\"", 
      "\"\\!\\(\\*SuperscriptBox[\\\"kJmol\\\", \\nRowBox[{\\\"-\\\", \\\"1\\\
\"}]]\\)\""], TraditionalForm]},
  AxesOrigin->{0, 0},
  ImageSize->{400, 300},
  PlotRange->{{-16.0546881, 15.0804648}, {0, 197.2273767596721}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.4374284536392317`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Redundant internal distance between TS structures is \"\>", 
   "\[InvisibleSpace]", "3.600962091068754`*^-8", 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "Redundant internal distance between TS structures is ", 
   3.600962091068754*^-8, "."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428453751379*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "61", "\[InvisibleSpace]", "\<\" internal coordinates will be used in \
fitting \\!\\(\\*SubscriptBox[\\\"V\\\", \\\"12\\\"]\\).\"\>"}],
  SequenceForm[
  61, " internal coordinates will be used in fitting \
\!\(\*SubscriptBox[\"V\", \"12\"]\)."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428453849547*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "0", ",", "0"}], "}"}]},
     {"2", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6", ",", "0", ",", "0"}], "}"}]},
     {"3", 
      RowBox[{"{", 
       RowBox[{"1", ",", "7", ",", "0", ",", "0"}], "}"}]},
     {"4", 
      RowBox[{"{", 
       RowBox[{"1", ",", "8", ",", "0", ",", "0"}], "}"}]},
     {"5", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "0", ",", "0"}], "}"}]},
     {"6", 
      RowBox[{"{", 
       RowBox[{"2", ",", "9", ",", "0", ",", "0"}], "}"}]},
     {"7", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4", ",", "0", ",", "0"}], "}"}]},
     {"8", 
      RowBox[{"{", 
       RowBox[{"3", ",", "10", ",", "0", ",", "0"}], "}"}]},
     {"9", 
      RowBox[{"{", 
       RowBox[{"3", ",", "11", ",", "0", ",", "0"}], "}"}]},
     {"10", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5", ",", "0", ",", "0"}], "}"}]},
     {"11", 
      RowBox[{"{", 
       RowBox[{"5", ",", "6", ",", "0", ",", "0"}], "}"}]},
     {"12", 
      RowBox[{"{", 
       RowBox[{"5", ",", "14", ",", "0", ",", "0"}], "}"}]},
     {"13", 
      RowBox[{"{", 
       RowBox[{"6", ",", "12", ",", "0", ",", "0"}], "}"}]},
     {"14", 
      RowBox[{"{", 
       RowBox[{"6", ",", "13", ",", "0", ",", "0"}], "}"}]},
     {"15", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "6", ",", "0"}], "}"}]},
     {"16", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "7", ",", "0"}], "}"}]},
     {"17", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "8", ",", "0"}], "}"}]},
     {"18", 
      RowBox[{"{", 
       RowBox[{"6", ",", "1", ",", "7", ",", "0"}], "}"}]},
     {"19", 
      RowBox[{"{", 
       RowBox[{"6", ",", "1", ",", "8", ",", "0"}], "}"}]},
     {"20", 
      RowBox[{"{", 
       RowBox[{"7", ",", "1", ",", "8", ",", "0"}], "}"}]},
     {"21", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "0"}], "}"}]},
     {"22", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "9", ",", "0"}], "}"}]},
     {"23", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2", ",", "9", ",", "0"}], "}"}]},
     {"24", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "4", ",", "0"}], "}"}]},
     {"25", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "10", ",", "0"}], "}"}]},
     {"26", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "11", ",", "0"}], "}"}]},
     {"27", 
      RowBox[{"{", 
       RowBox[{"4", ",", "3", ",", "10", ",", "0"}], "}"}]},
     {"28", 
      RowBox[{"{", 
       RowBox[{"4", ",", "3", ",", "11", ",", "0"}], "}"}]},
     {"29", 
      RowBox[{"{", 
       RowBox[{"10", ",", "3", ",", "11", ",", "0"}], "}"}]},
     {"30", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4", ",", "5", ",", "0"}], "}"}]},
     {"31", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5", ",", "6", ",", "0"}], "}"}]},
     {"32", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5", ",", "14", ",", "0"}], "}"}]},
     {"33", 
      RowBox[{"{", 
       RowBox[{"6", ",", "5", ",", "14", ",", "0"}], "}"}]},
     {"34", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6", ",", "5", ",", "0"}], "}"}]},
     {"35", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6", ",", "12", ",", "0"}], "}"}]},
     {"36", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6", ",", "13", ",", "0"}], "}"}]},
     {"37", 
      RowBox[{"{", 
       RowBox[{"5", ",", "6", ",", "12", ",", "0"}], "}"}]},
     {"38", 
      RowBox[{"{", 
       RowBox[{"5", ",", "6", ",", "13", ",", "0"}], "}"}]},
     {"39", 
      RowBox[{"{", 
       RowBox[{"12", ",", "6", ",", "13", ",", "0"}], "}"}]},
     {"40", 
      RowBox[{"{", 
       RowBox[{"6", ",", "1", ",", "2", ",", "3"}], "}"}]},
     {"41", 
      RowBox[{"{", 
       RowBox[{"6", ",", "1", ",", "2", ",", "9"}], "}"}]},
     {"42", 
      RowBox[{"{", 
       RowBox[{"7", ",", "1", ",", "2", ",", "3"}], "}"}]},
     {"43", 
      RowBox[{"{", 
       RowBox[{"8", ",", "1", ",", "2", ",", "9"}], "}"}]},
     {"44", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "6", ",", "5"}], "}"}]},
     {"45", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "6", ",", "13"}], "}"}]},
     {"46", 
      RowBox[{"{", 
       RowBox[{"7", ",", "1", ",", "6", ",", "5"}], "}"}]},
     {"47", 
      RowBox[{"{", 
       RowBox[{"7", ",", "1", ",", "6", ",", "12"}], "}"}]},
     {"48", 
      RowBox[{"{", 
       RowBox[{"8", ",", "1", ",", "6", ",", "12"}], "}"}]},
     {"49", 
      RowBox[{"{", 
       RowBox[{"8", ",", "1", ",", "6", ",", "13"}], "}"}]},
     {"50", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]},
     {"51", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "11"}], "}"}]},
     {"52", 
      RowBox[{"{", 
       RowBox[{"9", ",", "2", ",", "3", ",", "4"}], "}"}]},
     {"53", 
      RowBox[{"{", 
       RowBox[{"9", ",", "2", ",", "3", ",", "10"}], "}"}]},
     {"54", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "4", ",", "5"}], "}"}]},
     {"55", 
      RowBox[{"{", 
       RowBox[{"11", ",", "3", ",", "4", ",", "5"}], "}"}]},
     {"56", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4", ",", "5", ",", "6"}], "}"}]},
     {"57", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4", ",", "5", ",", "14"}], "}"}]},
     {"58", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5", ",", "6", ",", "1"}], "}"}]},
     {"59", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5", ",", "6", ",", "13"}], "}"}]},
     {"60", 
      RowBox[{"{", 
       RowBox[{"14", ",", "5", ",", "6", ",", "1"}], "}"}]},
     {"61", 
      RowBox[{"{", 
       RowBox[{"14", ",", "5", ",", "6", ",", "12"}], "}"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428453973053*^9}],

Cell[BoxData["\<\"Utilizing user supplied initial guess.\"\>"], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.4374284542986393`*^9}],

Cell[BoxData["\<\"Solving for B using GMRES.\"\>"], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.4374284543795147`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Current alpha values: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1.5`", ",", "1.5`", ",", "1.5`"}], "}"}]}],
  SequenceForm["Current alpha values: ", {1.5, 1.5, 1.5}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428454450426*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Norm of \\!\\(\\*SubscriptBox[\\\"r\\\", \\\"0\\\"]\\) = \"\>",
    "\[InvisibleSpace]", "5.841791866698978`*^-17", 
   "\[InvisibleSpace]", "\<\" , Dimensions: \"\>", "\[InvisibleSpace]", 
   "5859"}],
  SequenceForm[
  "Norm of \!\(\*SubscriptBox[\"r\", \"0\"]\) = ", 5.841791866698978*^-17, 
   " , Dimensions: ", 5859],
  Editable->False]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428456687454*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Iteration: \"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["Iteration: ", 1],
  Editable->False]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.4374284567536993`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Residual: \"\>", "\[InvisibleSpace]", 
   "5.841791866698978`*^-17"}],
  SequenceForm["Residual: ", 5.841791866698978*^-17],
  Editable->False]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428459255438*^9}],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0, 0, 1], LineBox[{{1., 1.}, {2., 5.841791866698978*^-17}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"GMRES step\"", TraditionalForm], 
    FormBox["\"Residual\"", TraditionalForm]},
  AxesOrigin->{0, Automatic},
  ImageSize->{400, 300},
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.4374284593726473`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Min element in B vector: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.018034966857917365`"}]}],
  SequenceForm["Min element in B vector: ", -0.018034966857917365`],
  Editable->False]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428459507468*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Max element in B vector: \"\>", "\[InvisibleSpace]", 
   "0.038197325813709104`"}],
  SequenceForm["Max element in B vector: ", 0.038197325813709104`],
  Editable->False]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428459563567*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Mean element in B vector: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "1.4330663974621239`*^-6"}]}],
  SequenceForm["Mean element in B vector: ", -1.4330663974621239`*^-6],
  Editable->False]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.4374284596342373`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Norm of B vector: \"\>", "\[InvisibleSpace]", 
   "0.09091410201316588`"}],
  SequenceForm["Norm of B vector: ", 0.09091410201316588],
  Editable->False]], "Print",
 CellChangeTimes->{{3.437231096739625*^9, 3.43723110350525*^9}, 
   3.437244720614625*^9, 3.4372447579115*^9, 3.4372550267865*^9, 
   3.437255071770875*^9, {3.43725510338025*^9, 3.437255168052125*^9}, 
   3.43732758064086*^9, 3.4373310753621693`*^9, 3.437395742952097*^9, 
   3.437399056955328*^9, 3.4373991155298023`*^9, 3.4374086555355473`*^9, {
   3.437409200095478*^9, 3.437409221699519*^9}, 3.437412583581915*^9, 
   3.437412935460438*^9, 3.437413351254505*^9, 3.437413406757147*^9, 
   3.437428459704121*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["store and dump beta if necessary", "Subsection",
 ScreenStyleEnvironment->"Presentation",
 PrintingStyleEnvironment->"Presentation",
 ShowCellLabel->False,
 Magnification->1.25],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"iFigures", "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"StoredBeta", "=", "$B"}], ";", 
      RowBox[{"PreviousnDG", "=", 
       RowBox[{"Length", "[", "$CoordDG", "]"}]}], ";"}]}], "]"}], ";"}], 
  " "}]], "Input"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"iDump", "\[Equal]", "1"}], ",", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"\"\<Beta-\>\"", "<>", 
      RowBox[{"ToString", "[", 
       RowBox[{"Length", "[", "$CoordDG", "]"}], "]"}], "<>", 
      "\"\<.txt\>\""}], ",", "$B", ",", "\"\<List\>\""}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.434826997366086*^9, 3.434826997772156*^9}, {
  3.434832645621215*^9, 3.4348326511043377`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Remove", "[", "Guess", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.4348272400822906`*^9, 3.4348272466618767`*^9}, {
  3.4348326615324*^9, 3.4348326799587812`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBinUse", "[", "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Currently using \"\>", "\[InvisibleSpace]", 
   "10.008529663085938`", "\[InvisibleSpace]", "\<\" MB of memory.\"\>"}],
  SequenceForm["Currently using ", 10.008529663085938`, " MB of memory."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.4372434226615*^9, 3.437250669114625*^9, 3.4372550527865*^9, {
   3.437255092364625*^9, 3.437255172864625*^9}, 3.4373276462333317`*^9, 
   3.437331096889311*^9, 3.437395755568035*^9, 3.437399070093008*^9, 
   3.4373991289389772`*^9, 3.437408668496966*^9, 3.43741294894648*^9, 
   3.437413365178754*^9, 3.437413420475841*^9, 3.4374284602086277`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Analyze the EVB Fit", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"First", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"V", "\[Equal]", " ", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["V", "11"], "+", 
             SubscriptBox["V", "22"]}], ")"}]}], "-", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               FractionBox["1", "2"], "*", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["V", "11"], "-", 
                 SubscriptBox["V", "22"]}], ")"}]}], ")"}], "2"], "+", "x"}], 
           "]"}]}]}], ",", "x"}], "]"}], "]"}], "/.", 
     RowBox[{"x", "\[Rule]", 
      SuperscriptBox[
       SubscriptBox["V", "12"], "2"]}]}], "]"}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.437339186173005*^9, 3.4373391883843307`*^9}}],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["V", "12", "2"], "\[Rule]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"V", "-", 
     SubscriptBox["V", "11"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"V", "-", 
     SubscriptBox["V", "22"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.43733918935921*^9, 3.437395831965209*^9, 
  3.437399139035681*^9, 3.437408676019188*^9, 3.437412949097754*^9, 
  3.437413365350039*^9, 3.437413420629324*^9, 3.43742846041617*^9, 
  3.437428859443326*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "AnalyzeEVBfit", "]"}]], "Input",
 CellChangeTimes->{{3.4374077555659847`*^9, 3.4374077635091677`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"AngleAnalysis", "\[Rule]", "False"}], ",", 
   RowBox[{"DecomposeV12", "\[Rule]", "False"}], ",", 
   RowBox[{"GradientNorm", "\[Rule]", "True"}], ",", 
   RowBox[{"HessianNorm", "\[Rule]", "False"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"400", ",", "300"}], "}"}]}], ",", 
   RowBox[{"V12Analysis", "\[Rule]", "True"}]}], "}"}]], "Output",
 CellChangeTimes->{3.43740776394527*^9, 3.437408677374529*^9, 
  3.437412949309499*^9, 3.437413365563484*^9, 3.437413420745775*^9, 
  3.4374284605317698`*^9, 3.4374288599128237`*^9, 3.437429379920282*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "AnalyzeEVBfit"}]], "Input",
 CellChangeTimes->{{3.437407731305887*^9, 3.4374077535814247`*^9}, 
   3.437408693896212*^9}],

Cell[BoxData[
 StyleBox["\<\"AnalyzeEVBfit[AtomicMass] analyzes the EVB fit along the IRC \
utilizing the current EVB global variables. AtomicMass is an optional \
argument containing the atomic mass for each atom in the system. AtomicMass \
is only required when AngleAnalysis is enabled.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.4374288603330584`*^9},
 CellTags->"Info3437410860-6854134"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AnalyzeEVBfit", "[", 
  RowBox[{"AtomicWeights", "[", "iTS", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.437333218794162*^9, 3.437333243521221*^9}, 
   3.4373336072593727`*^9, {3.437343985992947*^9, 3.4373439909852333`*^9}, 
   3.437345102779917*^9, {3.43739858081579*^9, 3.437398585274695*^9}, {
   3.437400086478726*^9, 3.4374000901734667`*^9}, {3.437400281224248*^9, 
   3.437400289291956*^9}, {3.437406880411166*^9, 3.437406882449649*^9}, 
   3.437407729403167*^9, 3.437412622457279*^9, {3.437428423647374*^9, 
   3.43742842885559*^9}, {3.4374286842790403`*^9, 3.4374287209232264`*^9}, {
   3.437429391626301*^9, 3.437429406801817*^9}, 3.43742958535275*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reaction barrier: \"\>", "\[InvisibleSpace]", 
   "195.2273767596721`", "\[InvisibleSpace]", "\<\" kJ/mol\"\>"}],
  SequenceForm["Reaction barrier: ", 195.2273767596721, " kJ/mol"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374284616628923`*^9, 3.4374287216537237`*^9, 3.437428860898498*^9, 
   3.437429425778459*^9}],

Cell[BoxData["\<\"Energies along the IRC:\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374284616628923`*^9, 3.4374287216537237`*^9, 3.437428860898498*^9, 
   3.43742951011267*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.005], LineBox[CompressedData["
1:eJwBMQTO+1JvYiFlAAAAAgAAAEIAAAACwDAOAAoQ+vpAWAO7wUZJKsAvdrJ2
CXGZQFgGFftJAJ/ALvjd6wJB+UBYCPFBudInwC35FwoHwL9AWBOySuqPNsAs
+UODDI9aQFgkf+lGw3HAK/lqty3/FkBYOq4MO0GxwCr5kCL4Uo1AWFaSvBGM
BcAp+bVcbb8gQFh3geg2nk7AKPnbGL/qZ0BYnXuQqqGTwCf6AaUbrdxAWMgp
rSQTwsAm+ijwuhHgQFj3YTl94cnAJfpQWotm0UBZKvcxk5yqwCT6drtIQApA
WWLAkUBaWcAj+psEJ9fgQFmevViEGtXAIvq9Def1HEBZ3u2HXt4ewCH63n+n
qv9AWiMmGavjLcAg+wM89lWHQFprvRe0rBDAH/Zhe3AN2kBauV6SDDzpwB32
1KGtZFJAWw3jtkczGsAb91XHh757QFtsJ8rWNyXAGffLINAvLUBb2QpH40/3
wBf4Ixk0r19AXFpsvnWFv8AV+GOKk+0yQFz3B9RK2LbAE/icYR8pvEBdtuxQ
R/VrwBH41P1H6c9AXqLXCeS1lsAP8hlKU+EpQF/FXgYswzHAC/KNVLzFxEBg
lOGtX48zwAfzM2DVgtRAYW26EK/YtcAD9PsvCtp6QGJzWkRE7Ma///QCyV4C
akBjr5a6hWLMv/f70KDB1vpAZSvt3Y47lr/v/M/Lc6AlQGa7l90amBO/3/6r
Bztu0kBn8kjKngMMAAAAAAAAAABAaGc8Do/Ibj/f/cs/4na3QGfy31kepqg/
7/ykmPwP3EBmq8xXmxMOP/f9TtrZf+RAZLGaFQQXrD///GD8RDO3QGIlTT+R
ZNdAA/3I6LyXdUBeeCjta2xsQAf9V9dXakpAWIMaBh9JjEAL/DGJj+E0QFMe
C/3jcTtAD/euT4kqNkBNuhAudN+bQBH4XbluoR1AR39wk7WGZ0AT9zsRzt93
QEK7hxEvru9AFfbeIFxA9EA9+CFKevaXQBf2pP6nkFJAOA/XnhidJ0AZ9nLD
7NRUQDNm0LKMYM5AG/ZBRRm6kUAvbPN3DgA3QB32FGNkU2dAKYticGnQBUAf
9exMbu51QCTRjeaBiHdAIPrfMtXrL0Ag/u+iMQ07QCH6vzHZluBAG8OVse05
d0Ai+pTkKDMlQBajl1C1Xj5AI/pkm7X+f0ASYA4r4nz5QCT6NUzo5t9ADZEr
NEEa4kAl+gyJez5lQAdps3HgrV5AJvnrus6dh0ACJBFwesptQCf50D5xVNc/
+yqCFrFXLUAo+bUV9uJKP/NlAnJ1WTxAKfmTs6aLGj/p2cXWYDsQQCr5Y+0P
YnQ/3wiOAwt+RkAr+R15jYqXP88mIZoREr9ALPjAGWAjVj+1TFAqOkW3QC14
ZD5t+dg/o75szehQAEAt1GqFr9fJP5H6xzi8RFRALikyrqj1Vz9dk5cFlHjl
a434VA==
     "]]}, 
   {RGBColor[0, 0, 1], Thickness[0.005], 
    LineBox[{{-16.0546881, 96.0572846776419}, {-15.7318303, 
     96.08970397974085}, {-15.486068099999999`, 
     96.13975843098714}, {-14.9865039, 96.32016880122346}, {-14.4868432, 
     96.6210877948269}, {-13.987142299999999`, 
     97.06441641977902}, {-13.4874278, 97.67463074662666}, {-12.9877118, 
     98.47843379765698}, {-12.487999700000001`, 
     99.50467442874164}, {-11.988293800000001`, 
     100.78447843547997`}, {-11.488593600000002`, 
     102.35138348203647`}, {-10.9888943, 
     104.2411281900253}, {-10.489187099999999`, 
     106.49070532443604`}, {-9.98946393, 109.13640473001368`}, {-9.48972362, 
     112.21065447774218`}, {-8.98997878, 115.73741201718362`}, {-8.49025908, 
     119.72554786157}, {-7.99060624, 124.159838522723}, {-7.4910455, 
     128.99210288028328`}, {-6.99153816, 134.1424693314097}, {-6.49198581, 
     139.5247389315881}, {-5.99232139, 145.09301775313807`}, {-5.49256722, 
     150.88046992536363`}, {-4.99278404, 157.0041999921483}, {-4.49299999, 
     163.64026483663665`}, {-3.9932123, 170.99064835972626`}, {-3.49343363, 
     179.25808275746482`}, {-2.99375034, 
     188.6350309750711}, {-2.5943926525871226`, 197.2273767596721}}]}, 
   {RGBColor[0., 0.75, 0.], Thickness[0.005], 
    LineBox[{{2.0024162031963457`, 197.2273767596721}, {2.49891836, 
     133.81671317921302`}, {2.9987027, 86.76116132362465}, {3.49814136, 
     56.60894779197281}, {3.99593794, 40.89723742488192}, {4.49254503, 
     33.53804765023764}, {4.99143627, 28.902053520430464`}, {5.49108172, 
     25.230992304060965`}, {5.99086378, 22.11293866319875}, {6.49067217, 
     19.35795955041798}, {6.99048336, 16.862683211354415`}, {7.49031215, 
     14.580278523372167`}, {7.99015922, 12.496941159708758`}, {8.48998412, 
     10.608389887923659`}, {8.98973995, 8.906298187271862}, {9.4894172, 
     7.37790309458705}, {9.98904883, 6.011159736390241}, {10.4886879, 
     4.797865718759997}, {10.9883769, 3.7334025859606306`}, {11.4881266, 
     2.8149154834332837`}, {11.9879169, 2.0395272890597544`}, {12.4877097, 
     1.4030921920352837`}, {12.987455, 0.899372369099167}, {13.4870905, 
     0.5195468275796146}, {13.986552999999999`, 0.2523209839213509}, {
     14.4858406, 0.08528991607213299}, {14.735139799999999`, 
     0.03633066925050948}, {14.914875199999999`, 0.013771955345094277`}, {
     15.0804648, 0.0025286919146076023`}}]}, 
   {GrayLevel[0], Thickness[0.004], LineBox[CompressedData["
1:eJwBMQTO+1JvYiFlAAAAAgAAAEIAAAACwDAOAAoQ+vpAWAOqjVpCK8AvdrJ2
CXGZQFgFvbXCBpjALvjd6wJB+UBYCPHNVOv8wC35FwoHwL9AWBR9pSjicMAs
+UODDI9aQFgnv+ZmEybAK/lqty3/FkBYRB9jhFj5wCr5kCL4Uo1AWGstHUR1
e8Ap+bVcbb8gQFienonrx6nAKPnbGL/qZ0BY4Ew0I2VawCf6AaUbrdxAWTIz
v5vPf8Am+ijwuhHgQFmWec51Fj3AJfpQWotm0UBaD2XVKYCjwCT6drtIQApA
Wp9RDHEhBMAj+psEJ9fgQFtIgzgsjZLAIvq9Def1HEBcDPivEZfnwCH63n+n
qv9AXO4K9it6acAg+wM89lWHQF3r7jf3GpDAH/Zhe3AN2kBfBPY9Rx49wB32
1KGtZFJAYBpi0gZMyMAb91XHh757QGC6B/H+3IzAGffLINAvLUBhXPjRE3kt
wBf4Ixk0r19AYf9sRJ+X6sAV+GOKk+0yQGKfjOpMf6fAE/icYR8pvEBjPa3u
NyglwBH41P1H6c9AY9tzReUkCMAP8hlKU+EpQGR6ealNMybAC/KNVLzFxEBl
GnTlBKbcwAfzM2DVgtRAZbUht083ycAD9PsvCtp6QGY0MaiNKwq///QCyV4C
akBmdwCzZRA6v/f70KDB1vpAZrJ6lROAtb/v/M/Lc6AlQGdFEy+9kcS/3/6r
Bztu0kBoBYQdExTDAAAAAAAAAABAaGdGq6Bpsz/f/cs/4na3QGfgFU6lmKw/
7/ykmPwP3EBmJYiitd1hP/f9TtrZf+RAYzgMWJmXtz///GD8RDO3QF7a7j0Q
gulAA/3I6LyXdUBW1G988xaeQAf9V9dXakpAT6mo3lPzb0AL/DGJj+E0QEXm
UPB8GXdAD/euT4kqNkBAw+Xu2SQtQBH4XbluoR1APLqGUvGIb0AT9zsRzt93
QDl9fBYwj4lAFfbeIFxA9EA21jinO3TvQBf2pP6nkFJANIJSg5FUNkAZ9nLD
7NRUQDJXWz/LAydAG/ZBRRm6kUAwQVCSEExyQB32FGNkU2dALHp2jarDekAf
9exMbu51QCiimCfl/5RAIPrfMtXrL0AlClZbSXhnQCH6vzHZluBAIbs/D8sf
6kAi+pTkKDMlQB1xA0LZ/npAI/pkm7X+f0AYBBhQZF4IQCT6NUzo5t9AEy4r
Xl3yx0Al+gyJez5lQA3b5rGhn+tAJvnrus6dh0AGhDOAB61wQCf50D5xVNdA
AFCzV5AkXUAo+bUV9uJKP/Zy597wQI5AKfmTs6aLGj/sx5B5IWN3QCr5Y+0P
YnQ/4KAaYySdRkAr+R15jYqXP9AmBEuDYjVALPjAGWAjVj+11Y4LiLSDQC14
ZD5t+dg/opnuZ650vkAt1GqFr9fJP4w0eCLJZdhALikyrqj1Vz9ktw0N4pNb
fGz2fA==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Reaction coordinate\"", TraditionalForm], 
    FormBox[
     FractionBox[
     "\"Energy\"", 
      "\"\\!\\(\\*SuperscriptBox[\\\"kJmol\\\", \\nRowBox[{\\\"-\\\", \\\"1\\\
\"}]]\\)\""], TraditionalForm]},
  AxesOrigin->{0, 0},
  ImageSize->{400, 300},
  PlotRange->{{-16.0546881, 15.0804648}, {0, 197.2273767596721}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374284616628923`*^9, 3.4374287216537237`*^9, 3.437428860898498*^9, 
   3.4374295102784843`*^9}],

Cell[BoxData["\<\"Red = IRC, Blue = \\!\\(\\*SubscriptBox[\\\"V\\\", \\\"11\\\
\"]\\), Green = \\!\\(\\*SubscriptBox[\\\"V\\\", \\\"22\\\"]\\), Black = \
EVB\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374284616628923`*^9, 3.4374287216537237`*^9, 3.437428860898498*^9, 
   3.437429510392891*^9}],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374284616628923`*^9, 3.4374287216537237`*^9, 3.437428860898498*^9, 
   3.4374295104496613`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Maximum energy error along the IRC: \"\>", "\[InvisibleSpace]",
    "36.74348746020078`", "\[InvisibleSpace]", "\<\" kJ/mol\"\>"}],
  SequenceForm[
  "Maximum energy error along the IRC: ", 36.74348746020078, " kJ/mol"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374284616628923`*^9, 3.4374287216537237`*^9, 3.437428860898498*^9, 
   3.437429510497662*^9}],

Cell[BoxData["\<\"Energy error along the IRC:\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374284616628923`*^9, 3.4374287216537237`*^9, 3.437428860898498*^9, 
   3.43742951055723*^9}],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.6, 0.4, 0.2], Thickness[0.005], LineBox[CompressedData["
1:eJwBMQTO+1JvYiFlAAAAAgAAAEIAAAACwDAOAAoQ+vq/UTPsBv8APsAvdrJ2
CXGZv3YRYb6BvRLALvjd6wJB+T8Bc2M6sMO9wC35FwoHwL8/iWtHymcqBcAs
+UODDI9aP6n/6Pp9o67AK/lqty3/Fj/C4q6SLpF4wCr5kCL4Uo0/1JphMul2
UsAp+bVcbb8gP+OOUNqUrWrAKPnbGL/qZz/wtCjeMPHkwCf6AaUbrdw/+oKE
ne7vEsAm+ijwuhHgQAPjEp7mjorAJfpQWotm0UAMjdRyvH8bwCT6drtIQApA
E8kHswxqp8Aj+psEJ9fgQBqcXfqHK8bAIvq9Def1HEAhcFk9lc5GwCH63n+n
qv9AJlcm4/y55cAg+wM89lWHQCwBiQITc/zAH/Zhe3AN2kAxLl6s64VRwB32
1KGtZFJANJuHtxWZ3MAb91XHh757QDgfoGSeB8zAGffLINAvLUA7g51pDomJ
wBf4Ixk0r19APpGvKyaoWMAV+GOKk+0yQECQJACcTTDAE/icYR8pvEBBiN8Y
TLW9wBH41P1H6c9AQigfA8sk9MAP8hlKU+EpQEJfKpjbRjTAC/KNVLzFxEBC
FkzelF6kwAfzM2DVgtRAQR2emn18U8AD9PsvCtp6QD4GuyJB8h+///QCyV4C
akA2O0/G/Wtxv/f70KDB1vpAKGjLeFRR6b/v/M/Lc6AlQBEvalRfNim/3/6r
Bztu0j/jO1J1EbcOAAAAAAAAAAA/VTohQohI1z/f/cs/4na3v+LKCnkN/Aw/
7/ykmPwP3MAQyHacprWgP/f9TtrZf+TAJ5jbxqf/Vj///GD8RDO3wDW+sQhJ
GxBAA/3I6LyXdcA+juXB4Vc7QAf9V9dXakrAQVyLLeqfqUAL/DGJj+E0wEBV
xwtKyP9AD/euT4kqNsA57FR/N3bcQBH4XbluoR3AMkRa1HmEX0AT9zsRzt93
wCfzJBhdnKxAFfbeIFxA9MAch6KM/gahQBf2pP6nkFLADGwo1DpHikAZ9nLD
7NRUv/D3VywV2m1AG/ZBRRm6kT/hWtrRKYrHQB32FGNkU2c/93ig6gebp0Af
9exMbu51P/6IUgsjuOZAIPrfMtXrL0AALZrkYaytQCH6vzHZluA//suhtqQZ
dEAi+pTkKDMlP/s1r8iSgPNAI/pkm7X+fz/2kCiSB4Q/QCT6NUzo5t8/8ZZX
EPWVWEAl+gyJez5lP+nIzP8DyjVAJvnrus6dhz/hgIg+M4wNQCf50D5xVNc/
1duSYbvGN0Ao+bUV9uJKP8hvK2PXOpFAKfmTs6aLGj+3blUWCUM1QCr5Y+0P
YnQ/ob02Ge3iLUAr+R15jYqXP4Jeb89bGrpALPjAGWAjVj9hJ7wpzdmcQC14
ZD5t+di/YkfmY520JUAt1GqFr9fJv28EWTq8iz5ALikyrqj1Vz9HtQYsYVuk
/h4J5g==
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Reaction coordinate\"", TraditionalForm], 
    FormBox[
     FractionBox[
     "\"Energy\"", 
      "\"\\!\\(\\*SuperscriptBox[\\\"kJmol\\\", \\nRowBox[{\\\"-\\\", \\\"1\\\
\"}]]\\)\""], TraditionalForm]},
  ImageSize->{400, 300},
  PlotRange->{-36.74348746020078, 36.74348746020078},
  PlotRangeClipping->True]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374284616628923`*^9, 3.4374287216537237`*^9, 3.437428860898498*^9, 
   3.437429510639819*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBinUse", "[", "]"}]], "Input",
 CellChangeTimes->{{3.4374073082264547`*^9, 3.437407310628818*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Currently using \"\>", "\[InvisibleSpace]", 
   "10.195930480957031`", "\[InvisibleSpace]", "\<\" MB of memory.\"\>"}],
  SequenceForm["Currently using ", 10.195930480957031`, " MB of memory."],
  Editable->False]], "Print",
 CellChangeTimes->{3.437407311125369*^9, 3.437408979449183*^9, 
  3.437413088450337*^9, 3.437413564045677*^9, 3.4374285515862083`*^9, 
  3.437428973120306*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1029, 846},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"6.0 for Mac OS X PowerPC (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3437410860-6854134"->{
  Cell[91511, 2161, 410, 7, 108, "Print",
   CellTags->"Info3437410860-6854134"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3437410860-6854134", 106549, 2460}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 172, 4, 107, "Subtitle"],
Cell[765, 29, 1368, 23, 534, "Text"],
Cell[CellGroupData[{
Cell[2158, 56, 32, 0, 100, "Section"],
Cell[CellGroupData[{
Cell[2215, 60, 200, 5, 40, "Input"],
Cell[2418, 67, 993, 17, 40, "Output"]
}, Open  ]],
Cell[3426, 87, 58, 1, 40, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3521, 93, 24, 0, 100, "Section"],
Cell[3548, 95, 232, 5, 39, "Text"],
Cell[CellGroupData[{
Cell[3805, 104, 172, 4, 42, "Subsection"],
Cell[3980, 110, 799, 18, 112, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4816, 133, 244, 7, 42, "Subsection"],
Cell[5063, 142, 678, 17, 162, "Input"],
Cell[5744, 161, 434, 11, 65, "Input"],
Cell[6181, 174, 726, 23, 133, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6944, 202, 48, 0, 51, "Subsection"],
Cell[6995, 204, 274, 8, 64, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7306, 217, 116, 3, 51, "Subsection"],
Cell[7425, 222, 120, 3, 40, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7582, 230, 212, 5, 42, "Subsection"],
Cell[CellGroupData[{
Cell[7819, 239, 56, 1, 40, "Input"],
Cell[7878, 242, 790, 12, 40, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8717, 260, 278, 6, 42, "Subsection"],
Cell[8998, 268, 255, 6, 40, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9290, 279, 193, 4, 42, "Subsection"],
Cell[9486, 285, 478, 9, 40, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10013, 300, 28, 0, 100, "Section"],
Cell[CellGroupData[{
Cell[10066, 304, 62, 0, 37, "Subsubsection"],
Cell[10131, 306, 315, 9, 49, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[10483, 320, 107, 2, 26, "Subsubsection"],
Cell[10593, 324, 259, 9, 39, "Input"],
Cell[10855, 335, 259, 9, 39, "Input"],
Cell[11117, 346, 228, 6, 39, "Input"],
Cell[11348, 354, 227, 6, 39, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[11612, 365, 55, 1, 29, "Input"],
Cell[11670, 368, 1069, 18, 70, "Print"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[12788, 392, 39, 0, 53, "Section"],
Cell[CellGroupData[{
Cell[12852, 396, 513, 9, 40, "Input"],
Cell[13368, 407, 1896, 28, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15301, 440, 115, 1, 37, "Subsubsection"],
Cell[15419, 443, 2367, 58, 386, "Input"]
}, Closed]],
Cell[17801, 504, 3837, 88, 260, "Input"],
Cell[CellGroupData[{
Cell[21663, 596, 1611, 37, 179, "Input"],
Cell[23277, 635, 2433, 36, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25747, 676, 62, 1, 40, "Input"],
Cell[25812, 679, 3151, 55, 170, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29000, 739, 1157, 21, 87, "Input"],
Cell[30160, 762, 738, 14, 30, "Print"],
Cell[30901, 778, 588, 8, 30, "Print"],
Cell[31492, 788, 566, 8, 30, "Print"],
Cell[32061, 798, 566, 8, 30, "Print"],
Cell[32630, 808, 569, 8, 30, "Print"],
Cell[33202, 818, 582, 8, 30, "Print"],
Cell[33787, 828, 763, 13, 30, "Print"],
Cell[34553, 843, 768, 13, 30, "Print"],
Cell[35324, 858, 754, 13, 30, "Print"],
Cell[36081, 873, 6760, 206, 1291, "Print"],
Cell[42844, 1081, 928, 19, 30, "Print"],
Cell[43775, 1102, 571, 8, 30, "Print"],
Cell[44349, 1112, 4591, 98, 73, "Print"],
Cell[48943, 1212, 570, 8, 30, "Print"],
Cell[49516, 1222, 6253, 105, 73, "Print"],
Cell[55772, 1329, 570, 8, 30, "Print"],
Cell[56345, 1339, 7295, 147, 85, "Print"],
Cell[63643, 1488, 846, 14, 30, "Print"],
Cell[64492, 1504, 711, 10, 30, "Print"],
Cell[65206, 1516, 5033, 88, 462, "Print"],
Cell[70242, 1606, 852, 16, 34, "Print"],
Cell[71097, 1624, 839, 16, 30, "Print"],
Cell[71939, 1642, 6760, 206, 1291, "Print"],
Cell[78702, 1850, 589, 8, 30, "Print"],
Cell[79294, 1860, 577, 8, 30, "Print"],
Cell[79874, 1870, 777, 14, 30, "Print"],
Cell[80654, 1886, 917, 17, 34, "Print"],
Cell[81574, 1905, 675, 12, 30, "Print"],
Cell[82252, 1919, 718, 13, 34, "Print"],
Cell[82973, 1934, 921, 19, 462, "Print"],
Cell[83897, 1955, 761, 13, 30, "Print"],
Cell[84661, 1970, 745, 13, 30, "Print"],
Cell[85409, 1985, 769, 13, 34, "Print"],
Cell[86181, 2000, 728, 13, 30, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86946, 2018, 183, 4, 42, "Subsection"],
Cell[87132, 2024, 310, 10, 40, "Input"],
Cell[87445, 2036, 466, 12, 40, "Input"],
Cell[87914, 2050, 200, 4, 40, "Input"],
Cell[CellGroupData[{
Cell[88139, 2058, 55, 1, 40, "Input"],
Cell[88197, 2061, 645, 11, 30, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[88903, 2079, 38, 0, 100, "Section"],
Cell[CellGroupData[{
Cell[88966, 2083, 1050, 31, 132, "Input"],
Cell[90019, 2116, 487, 13, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[90543, 2134, 142, 2, 40, "Input"],
Cell[90688, 2138, 633, 13, 64, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[91358, 2156, 150, 3, 40, "Input"],
Cell[91511, 2161, 410, 7, 108, "Print",
 CellTags->"Info3437410860-6854134"]
}, Open  ]],
Cell[CellGroupData[{
Cell[91958, 2173, 687, 10, 40, "Input"],
Cell[92648, 2185, 743, 13, 30, "Print"],
Cell[93394, 2200, 539, 8, 30, "Print"],
Cell[93936, 2210, 6549, 115, 462, "Print"],
Cell[100488, 2327, 656, 10, 30, "Print"],
Cell[101147, 2339, 519, 8, 30, "Print"],
Cell[101669, 2349, 782, 14, 30, "Print"],
Cell[102454, 2365, 543, 8, 30, "Print"],
Cell[103000, 2375, 2494, 48, 462, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[105531, 2428, 123, 2, 40, "Input"],
Cell[105657, 2432, 433, 8, 30, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
